import { Directive, ViewContainerRef, Injectable, Component, Inject, ReflectiveInjector, Input, NgZone, ComponentFactoryResolver, ViewChild, NgModule, ApplicationRef } from '@angular/core';
import { MatDialogRef, MAT_DIALOG_DATA, MatDialog, MatButtonModule, MatCheckboxModule, MatDialogModule, MatFormFieldModule, MatIconModule, MatInputModule, MatMenuModule, MatOptionModule, MatProgressBarModule, MatProgressSpinnerModule, MatSelectModule, MatTooltipModule } from '@angular/material';
import { FormControl, FormsModule, ReactiveFormsModule } from '@angular/forms';
import * as Resumable from 'resumablejs';
import { createHash } from 'crypto-browserify';
import { saveAs } from 'file-saver';
import { BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { FlexLayoutModule } from '@angular/flex-layout';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/enums/custom-event-type.enum.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
const CustomEventType = {
    UNKNOWN: 0,
    // This event can be used to bootstrap the app module. An IAppConfig can be passed as detail payload.
    CREATE: 1,
    // This event can be used to trigger an item download. The filename, url and size can be passed as detail payload.
    DOWNLOAD_ITEM: 2,
    // This event can be used to update the app configuration. An IAppConfig can be passed as detail payload.
    UPDATE_CONFIG: 3,
    // Indicates that the app has been initialized.
    INIT: 4,
    // Indicates that the overall upload has been completed.
    UPLOAD_COMPLETED: 5,
    // Indicates that the overall download has been completed.
    DOWNLOAD_COMPLETED: 6,
    // Indicates that an item has been added. It will be passed a IDatatransferItem as detail payload.
    ITEM_ADDED: 7,
    // Indicates that an item has been removed. It will be passed a IDatatransferItem as detail payload.
    ITEM_REMOVED: 8,
    // Indicates that an item has been completed.
    ITEM_COMPLETED: 9,
    // Indicates that all items have been cleared.
    ITEMS_CLEARED: 10,
};
CustomEventType[CustomEventType.UNKNOWN] = 'UNKNOWN';
CustomEventType[CustomEventType.CREATE] = 'CREATE';
CustomEventType[CustomEventType.DOWNLOAD_ITEM] = 'DOWNLOAD_ITEM';
CustomEventType[CustomEventType.UPDATE_CONFIG] = 'UPDATE_CONFIG';
CustomEventType[CustomEventType.INIT] = 'INIT';
CustomEventType[CustomEventType.UPLOAD_COMPLETED] = 'UPLOAD_COMPLETED';
CustomEventType[CustomEventType.DOWNLOAD_COMPLETED] = 'DOWNLOAD_COMPLETED';
CustomEventType[CustomEventType.ITEM_ADDED] = 'ITEM_ADDED';
CustomEventType[CustomEventType.ITEM_REMOVED] = 'ITEM_REMOVED';
CustomEventType[CustomEventType.ITEM_COMPLETED] = 'ITEM_COMPLETED';
CustomEventType[CustomEventType.ITEMS_CLEARED] = 'ITEMS_CLEARED';
// tslint:disable-next-line: no-namespace
var CustomEventTypeExtensions;
(function (CustomEventTypeExtensions) {
    /** @type {?} */
    const CUSTOM_EVENT_TYPE_NS = 'github:niklr/angular-material-datatransfer.';
    /** @type {?} */
    const CUSTOM_EVENT_TYPE_UNKNOWN = CUSTOM_EVENT_TYPE_NS + 'unknown';
    /** @type {?} */
    const CUSTOM_EVENT_TYPE_CREATE = CUSTOM_EVENT_TYPE_NS + 'create';
    /** @type {?} */
    const CUSTOM_EVENT_TYPE_DOWNLOAD_ITEM = CUSTOM_EVENT_TYPE_NS + 'download-item';
    /** @type {?} */
    const CUSTOM_EVENT_TYPE_UPDATE_CONFIG = CUSTOM_EVENT_TYPE_NS + 'update-config';
    /** @type {?} */
    const CUSTOM_EVENT_TYPE_INIT = CUSTOM_EVENT_TYPE_NS + 'init';
    /** @type {?} */
    const CUSTOM_EVENT_TYPE_UPLOAD_COMPLETED = CUSTOM_EVENT_TYPE_NS + 'upload-completed';
    /** @type {?} */
    const CUSTOM_EVENT_TYPE_DOWNLOAD_COMPLETED = CUSTOM_EVENT_TYPE_NS + 'download-completed';
    /** @type {?} */
    const CUSTOM_EVENT_TYPE_ITEM_ADDED = CUSTOM_EVENT_TYPE_NS + 'item-added';
    /** @type {?} */
    const CUSTOM_EVENT_TYPE_ITEM_REMOVED = CUSTOM_EVENT_TYPE_NS + 'item-removed';
    /** @type {?} */
    const CUSTOM_EVENT_TYPE_ITEM_COMPLETED = CUSTOM_EVENT_TYPE_NS + 'item-completed';
    /** @type {?} */
    const CUSTOM_EVENT_TYPE_ITEMS_CLEARED = CUSTOM_EVENT_TYPE_NS + 'items-cleared';
    /**
     * @param {?} type
     * @return {?}
     */
    function toString(type) {
        switch (type) {
            case CustomEventType.CREATE:
                return CUSTOM_EVENT_TYPE_CREATE;
            case CustomEventType.DOWNLOAD_ITEM:
                return CUSTOM_EVENT_TYPE_DOWNLOAD_ITEM;
            case CustomEventType.UPDATE_CONFIG:
                return CUSTOM_EVENT_TYPE_UPDATE_CONFIG;
            case CustomEventType.INIT:
                return CUSTOM_EVENT_TYPE_INIT;
            case CustomEventType.UPLOAD_COMPLETED:
                return CUSTOM_EVENT_TYPE_UPLOAD_COMPLETED;
            case CustomEventType.DOWNLOAD_COMPLETED:
                return CUSTOM_EVENT_TYPE_DOWNLOAD_COMPLETED;
            case CustomEventType.ITEM_ADDED:
                return CUSTOM_EVENT_TYPE_ITEM_ADDED;
            case CustomEventType.ITEM_REMOVED:
                return CUSTOM_EVENT_TYPE_ITEM_REMOVED;
            case CustomEventType.ITEM_COMPLETED:
                return CUSTOM_EVENT_TYPE_ITEM_COMPLETED;
            case CustomEventType.ITEMS_CLEARED:
                return CUSTOM_EVENT_TYPE_ITEMS_CLEARED;
            default:
                return CUSTOM_EVENT_TYPE_UNKNOWN;
        }
    }
    CustomEventTypeExtensions.toString = toString;
    /**
     * @param {?} type
     * @return {?}
     */
    function toEnum(type) {
        switch (type) {
            case CUSTOM_EVENT_TYPE_CREATE:
                return CustomEventType.CREATE;
            case CUSTOM_EVENT_TYPE_DOWNLOAD_ITEM:
                return CustomEventType.DOWNLOAD_ITEM;
            case CUSTOM_EVENT_TYPE_UPDATE_CONFIG:
                return CustomEventType.UPDATE_CONFIG;
            case CUSTOM_EVENT_TYPE_INIT:
                return CustomEventType.INIT;
            case CUSTOM_EVENT_TYPE_UPLOAD_COMPLETED:
                return CustomEventType.UPLOAD_COMPLETED;
            case CUSTOM_EVENT_TYPE_DOWNLOAD_COMPLETED:
                return CustomEventType.DOWNLOAD_COMPLETED;
            case CUSTOM_EVENT_TYPE_ITEM_ADDED:
                return CustomEventType.ITEM_ADDED;
            case CUSTOM_EVENT_TYPE_ITEM_REMOVED:
                return CustomEventType.ITEM_REMOVED;
            case CUSTOM_EVENT_TYPE_ITEM_COMPLETED:
                return CustomEventType.ITEM_COMPLETED;
            case CUSTOM_EVENT_TYPE_ITEMS_CLEARED:
                return CustomEventType.ITEMS_CLEARED;
            default:
                return CustomEventType.UNKNOWN;
        }
    }
    CustomEventTypeExtensions.toEnum = toEnum;
})(CustomEventTypeExtensions || (CustomEventTypeExtensions = {}));

/**
 * @fileoverview added by tsickle
 * Generated from: lib/directives/host.directive.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class HostDirective {
    /**
     * @param {?} viewContainerRef
     */
    constructor(viewContainerRef) {
        this.viewContainerRef = viewContainerRef;
    }
}
HostDirective.decorators = [
    { type: Directive, args: [{
                // tslint:disable-next-line: directive-selector
                selector: '[amd-host]',
            },] }
];
/** @nocollapse */
HostDirective.ctorParameters = () => [
    { type: ViewContainerRef }
];
if (false) {
    /** @type {?} */
    HostDirective.prototype.viewContainerRef;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/models/app-config.model.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CoreAppConfig {
    constructor() {
        this.showUploadDropzone = true;
        this.uploadBrowseElementId = undefined;
        this.uploadDropElementId = undefined;
        this.paginationRppOptions = [5, 10, 25];
        this.simultaneousDownloads = 2;
        this.downloadMethod = 'GET';
        this.downloadHeaders = {};
        this.downloadWithCredentials = false;
        this.downloadXhrTimeout = 0;
        this.preprocessHashEnabled = false;
        this.preprocessHashChecked = true;
        this.preprocessHashTarget = 'https://httpbin.org';
        this.preprocessHashMethod = 'GET';
        this.preprocessHashParameterName = 'hash';
        this.preprocessHashFileNameParameterName = 'filename';
        this.preprocessHashFunctionName = 'sha1';
        this.preprocessHashEncodingName = 'hex';
        this.preprocessHashInputEncodingName = 'latin1';
        this.preprocessHashTooltipContent = 'The preprocess option checks if the file is already on the system before uploading.';
        this.parseMessageCallback = (/**
         * @param {?} message
         * @return {?}
         */
        function (message) {
            return message;
        });
        this.getTarget = (/**
         * @param {?} request
         * @param {?} params
         * @return {?}
         */
        function (request, params) {
            /** @type {?} */
            let target;
            if (request === 'preprocessHash' && this.preprocessHashChecked) {
                target = this.preprocessHashTarget;
            }
            if (typeof target === 'function') {
                return target(params);
            }
            if (target) {
                /** @type {?} */
                const separator = target.indexOf('?') < 0 ? '?' : '&';
                /** @type {?} */
                const joinedParams = params.join('&');
                return target + separator + joinedParams;
            }
            else {
                return;
            }
        });
    }
}
if (false) {
    /** @type {?} */
    CoreAppConfig.prototype.showUploadDropzone;
    /** @type {?} */
    CoreAppConfig.prototype.uploadBrowseElementId;
    /** @type {?} */
    CoreAppConfig.prototype.uploadDropElementId;
    /** @type {?} */
    CoreAppConfig.prototype.paginationRppOptions;
    /** @type {?} */
    CoreAppConfig.prototype.simultaneousDownloads;
    /** @type {?} */
    CoreAppConfig.prototype.downloadMethod;
    /** @type {?} */
    CoreAppConfig.prototype.downloadHeaders;
    /** @type {?} */
    CoreAppConfig.prototype.downloadWithCredentials;
    /** @type {?} */
    CoreAppConfig.prototype.downloadXhrTimeout;
    /** @type {?} */
    CoreAppConfig.prototype.preprocessHashEnabled;
    /** @type {?} */
    CoreAppConfig.prototype.preprocessHashChecked;
    /** @type {?} */
    CoreAppConfig.prototype.preprocessHashTarget;
    /** @type {?} */
    CoreAppConfig.prototype.preprocessHashMethod;
    /** @type {?} */
    CoreAppConfig.prototype.preprocessHashParameterName;
    /** @type {?} */
    CoreAppConfig.prototype.preprocessHashFileNameParameterName;
    /** @type {?} */
    CoreAppConfig.prototype.preprocessHashFunctionName;
    /** @type {?} */
    CoreAppConfig.prototype.preprocessHashEncodingName;
    /** @type {?} */
    CoreAppConfig.prototype.preprocessHashInputEncodingName;
    /** @type {?} */
    CoreAppConfig.prototype.preprocessHashTooltipContent;
    /** @type {?} */
    CoreAppConfig.prototype.parseMessageCallback;
    /** @type {?} */
    CoreAppConfig.prototype.getTarget;
}
class ResumableJsAppConfig {
    constructor() {
        this.chunkSize = 1 * 1024 * 1024;
        this.forceChunkSize = false;
        this.simultaneousUploads = 3;
        this.fileParameterName = 'file';
        this.chunkNumberParameterName = 'resumableChunkNumber';
        this.chunkSizeParameterName = 'resumableChunkSize';
        this.currentChunkSizeParameterName = 'resumableCurrentChunkSize';
        this.totalSizeParameterName = 'resumableTotalSize';
        this.typeParameterName = 'resumableType';
        this.identifierParameterName = 'resumableIdentifier';
        this.fileNameParameterName = 'resumableFilename';
        this.relativePathParameterName = 'resumableRelativePath';
        this.totalChunksParameterName = 'resumableTotalChunks';
        this.throttleProgressCallbacks = 0.5;
        this.query = {};
        this.headers = {};
        this.preprocess = null;
        this.preprocessFile = null;
        this.method = 'multipart';
        this.uploadMethod = 'POST';
        this.testMethod = 'GET';
        this.target = 'https://httpbin.org';
        this.testTarget = null;
        this.parameterNamespace = '';
        this.testChunks = true;
        this.generateUniqueIdentifier = null;
        this.getTarget = null;
        this.maxChunkRetries = 100;
        this.chunkRetryInterval = undefined;
        this.permanentErrors = [400, 404, 405, 415, 501];
        this.maxFiles = undefined;
        this.withCredentials = false;
        this.xhrTimeout = 0;
        this.clearInput = true;
        this.chunkFormat = 'blob';
        this.minFileSize = 1;
        this.maxFileSize = undefined;
        this.fileType = [];
        this.maxFilesErrorCallback = (/**
         * @param {?} files
         * @param {?} errorCount
         * @return {?}
         */
        function (files, errorCount) {
            alert('Please upload no more than ' + this.maxFiles + ' file' + (this.maxFiles === 1 ? '' : 's') + ' at a time.');
        });
        this.minFileSizeErrorCallback = (/**
         * @param {?} file
         * @param {?} errorCount
         * @return {?}
         */
        function (file, errorCount) {
            alert(file.fileName || file.name + ' is too small; please upload files larger than ' + this.minFileSize + '.');
        });
        this.maxFileSizeErrorCallback = (/**
         * @param {?} file
         * @param {?} errorCount
         * @return {?}
         */
        function (file, errorCount) {
            alert(file.fileName || file.name + ' is too large; please upload files less than ' + this.maxFileSize + '.');
        });
        this.fileTypeErrorCallback = (/**
         * @param {?} file
         * @param {?} errorCount
         * @return {?}
         */
        function (file, errorCount) {
            alert(file.fileName || file.name + ' has type not allowed; please upload files of type ' + this.fileType + '.');
        });
    }
}
if (false) {
    /** @type {?} */
    ResumableJsAppConfig.prototype.chunkSize;
    /** @type {?} */
    ResumableJsAppConfig.prototype.forceChunkSize;
    /** @type {?} */
    ResumableJsAppConfig.prototype.simultaneousUploads;
    /** @type {?} */
    ResumableJsAppConfig.prototype.fileParameterName;
    /** @type {?} */
    ResumableJsAppConfig.prototype.chunkNumberParameterName;
    /** @type {?} */
    ResumableJsAppConfig.prototype.chunkSizeParameterName;
    /** @type {?} */
    ResumableJsAppConfig.prototype.currentChunkSizeParameterName;
    /** @type {?} */
    ResumableJsAppConfig.prototype.totalSizeParameterName;
    /** @type {?} */
    ResumableJsAppConfig.prototype.typeParameterName;
    /** @type {?} */
    ResumableJsAppConfig.prototype.identifierParameterName;
    /** @type {?} */
    ResumableJsAppConfig.prototype.fileNameParameterName;
    /** @type {?} */
    ResumableJsAppConfig.prototype.relativePathParameterName;
    /** @type {?} */
    ResumableJsAppConfig.prototype.totalChunksParameterName;
    /** @type {?} */
    ResumableJsAppConfig.prototype.throttleProgressCallbacks;
    /** @type {?} */
    ResumableJsAppConfig.prototype.query;
    /** @type {?} */
    ResumableJsAppConfig.prototype.headers;
    /** @type {?} */
    ResumableJsAppConfig.prototype.preprocess;
    /** @type {?} */
    ResumableJsAppConfig.prototype.preprocessFile;
    /** @type {?} */
    ResumableJsAppConfig.prototype.method;
    /** @type {?} */
    ResumableJsAppConfig.prototype.uploadMethod;
    /** @type {?} */
    ResumableJsAppConfig.prototype.testMethod;
    /** @type {?} */
    ResumableJsAppConfig.prototype.prioritizeFirstAndLastChunk;
    /** @type {?} */
    ResumableJsAppConfig.prototype.target;
    /** @type {?} */
    ResumableJsAppConfig.prototype.testTarget;
    /** @type {?} */
    ResumableJsAppConfig.prototype.parameterNamespace;
    /** @type {?} */
    ResumableJsAppConfig.prototype.testChunks;
    /** @type {?} */
    ResumableJsAppConfig.prototype.generateUniqueIdentifier;
    /** @type {?} */
    ResumableJsAppConfig.prototype.getTarget;
    /** @type {?} */
    ResumableJsAppConfig.prototype.maxChunkRetries;
    /** @type {?} */
    ResumableJsAppConfig.prototype.chunkRetryInterval;
    /** @type {?} */
    ResumableJsAppConfig.prototype.permanentErrors;
    /** @type {?} */
    ResumableJsAppConfig.prototype.maxFiles;
    /** @type {?} */
    ResumableJsAppConfig.prototype.withCredentials;
    /** @type {?} */
    ResumableJsAppConfig.prototype.xhrTimeout;
    /** @type {?} */
    ResumableJsAppConfig.prototype.clearInput;
    /** @type {?} */
    ResumableJsAppConfig.prototype.chunkFormat;
    /** @type {?} */
    ResumableJsAppConfig.prototype.minFileSize;
    /** @type {?} */
    ResumableJsAppConfig.prototype.maxFileSize;
    /** @type {?} */
    ResumableJsAppConfig.prototype.fileType;
    /** @type {?} */
    ResumableJsAppConfig.prototype.maxFilesErrorCallback;
    /** @type {?} */
    ResumableJsAppConfig.prototype.minFileSizeErrorCallback;
    /** @type {?} */
    ResumableJsAppConfig.prototype.maxFileSizeErrorCallback;
    /** @type {?} */
    ResumableJsAppConfig.prototype.fileTypeErrorCallback;
}
/**
 * @record
 */
function IAppConfig() { }
if (false) {
    /** @type {?} */
    IAppConfig.prototype.production;
    /** @type {?} */
    IAppConfig.prototype.core;
    /** @type {?} */
    IAppConfig.prototype.resumablejs;
}
class AppConfig {
    constructor() {
        this.production = true;
        this.core = new CoreAppConfig();
        this.resumablejs = new ResumableJsAppConfig();
    }
}
if (false) {
    /** @type {?} */
    AppConfig.prototype.production;
    /** @type {?} */
    AppConfig.prototype.core;
    /** @type {?} */
    AppConfig.prototype.resumablejs;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/services/config.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ConfigService {
    constructor() {
    }
    /**
     * @param {?} config
     * @return {?}
     */
    load(config) {
        if (!!config) {
            ConfigService.settings.production = config.production;
            if (!!config.core) {
                Object.keys(config.core).forEach((/**
                 * @param {?} propertyName
                 * @return {?}
                 */
                propertyName => {
                    if (typeof config.core[propertyName] !== 'undefined') {
                        ConfigService.settings.core[propertyName] = config.core[propertyName];
                    }
                }));
            }
            if (!!config.resumablejs) {
                Object.keys(config.resumablejs).forEach((/**
                 * @param {?} propertyName
                 * @return {?}
                 */
                propertyName => {
                    if (typeof config.resumablejs[propertyName] !== 'undefined') {
                        ConfigService.settings.resumablejs[propertyName] = config.resumablejs[propertyName];
                    }
                }));
            }
        }
    }
}
ConfigService.settings = new AppConfig();
ConfigService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
ConfigService.ctorParameters = () => [];
if (false) {
    /** @type {?} */
    ConfigService.settings;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/enums/transfer-status.enum.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
const TransferStatus = {
    Ready: 0,
    Queued: 1,
    Preprocessing: 2,
    Uploading: 3,
    Downloading: 4,
    Finished: 5,
    Failed: 6,
};
TransferStatus[TransferStatus.Ready] = 'Ready';
TransferStatus[TransferStatus.Queued] = 'Queued';
TransferStatus[TransferStatus.Preprocessing] = 'Preprocessing';
TransferStatus[TransferStatus.Uploading] = 'Uploading';
TransferStatus[TransferStatus.Downloading] = 'Downloading';
TransferStatus[TransferStatus.Finished] = 'Finished';
TransferStatus[TransferStatus.Failed] = 'Failed';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/enums/transfer-type.enum.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
const TransferType = {
    Upload: 0,
    Download: 1,
};
TransferType[TransferType.Upload] = 'Upload';
TransferType[TransferType.Download] = 'Download';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/browse-dialog.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BrowseDialogComponent {
    /**
     * @param {?} dialogRef
     * @param {?} data
     */
    constructor(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
        this.datatransferFacade = (/** @type {?} */ (this.data.datatransferFacade));
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.datatransferFacade.assignUploadBrowse(document.getElementById('amd-browse-files'));
        this.datatransferFacade.assignUploadBrowse(document.getElementById('amd-browse-folder'), true);
    }
    /**
     * @return {?}
     */
    close() {
        this.dialogRef.close();
    }
    /**
     * @return {?}
     */
    onNoClick() {
        this.close();
    }
}
BrowseDialogComponent.decorators = [
    { type: Component, args: [{
                // tslint:disable-next-line:component-selector
                selector: 'amd-browse-dialog',
                template: "<mat-dialog-content>Select specific files or a folder</mat-dialog-content>\r\n<mat-dialog-actions>\r\n    <button mat-raised-button id=\"amd-browse-files\" (click)=\"close()\" tabindex=\"1\">\r\n        <mat-icon>insert_drive_file</mat-icon> Files</button>\r\n    <button mat-raised-button id=\"amd-browse-folder\" (click)=\"close()\" tabindex=\"2\">\r\n        <mat-icon>folder_open</mat-icon> Folder</button>\r\n</mat-dialog-actions>"
            }] }
];
/** @nocollapse */
BrowseDialogComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];
if (false) {
    /** @type {?} */
    BrowseDialogComponent.prototype.datatransferFacade;
    /** @type {?} */
    BrowseDialogComponent.prototype.dialogRef;
    /** @type {?} */
    BrowseDialogComponent.prototype.data;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/edit-dialog.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class EditDialogComponent {
    /**
     * @param {?} dialogRef
     * @param {?} data
     */
    constructor(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
        this.datatransferFacade = (/** @type {?} */ (this.data.datatransferFacade));
        this.mode = this.data.mode;
        this.item = (/** @type {?} */ (this.data.item));
        this.itemPath = this.item.path;
        this.itemName = this.item.name;
        this.editFormControl = new FormControl('', []);
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
    }
    /**
     * @return {?}
     */
    close() {
        this.dialogRef.close();
    }
    /**
     * @return {?}
     */
    onNoClick() {
        this.close();
    }
    /**
     * @return {?}
     */
    editPath() {
        try {
            this.datatransferFacade.editPath(this.item, this.item.path, this.itemPath);
            this.close();
        }
        catch (error) {
            this.errorMessage = error;
        }
    }
    /**
     * @return {?}
     */
    editFilename() {
        try {
            this.datatransferFacade.editFilename(this.item, this.itemName);
            this.close();
        }
        catch (error) {
            this.errorMessage = error;
        }
    }
}
EditDialogComponent.decorators = [
    { type: Component, args: [{
                // tslint:disable-next-line:component-selector
                selector: 'amd-edit-dialog',
                template: "<div *ngIf=\"mode === 'edit-path'\">\r\n    <mat-dialog-content>\r\n        <p>Enter a new path:</p>\r\n        <form>\r\n            <mat-form-field>\r\n                <input matInput autocomplete=\"off\" tabindex=\"1\" [value]=\"itemPath\"\r\n                    (input)=\"itemPath = $event.target.value; errorMessage = undefined;\" [formControl]=\"editFormControl\">\r\n            </mat-form-field>\r\n            <mat-error *ngIf=\"errorMessage\">\r\n                {{errorMessage}}\r\n            </mat-error>\r\n        </form>\r\n    </mat-dialog-content>\r\n    <mat-dialog-actions>\r\n        <button mat-raised-button (click)=\"editPath()\" tabindex=\"2\">Ok</button>\r\n        <button mat-raised-button (click)=\"close()\" tabindex=\"-1\">Cancel</button>\r\n    </mat-dialog-actions>\r\n</div>\r\n<div *ngIf=\"mode === 'edit-filename'\">\r\n    <mat-dialog-content>\r\n        <p>Enter a new filename:</p>\r\n        <form>\r\n            <mat-form-field>\r\n                <input matInput autocomplete=\"off\" tabindex=\"1\" [value]=\"itemName\"\r\n                    (input)=\"itemName = $event.target.value; errorMessage = undefined;\" [formControl]=\"editFormControl\">\r\n            </mat-form-field>\r\n            <mat-error *ngIf=\"errorMessage\">\r\n                {{errorMessage}}\r\n            </mat-error>\r\n        </form>\r\n    </mat-dialog-content>\r\n    <mat-dialog-actions>\r\n        <button mat-raised-button (click)=\"editFilename()\" tabindex=\"2\">Ok</button>\r\n        <button mat-raised-button (click)=\"close()\" tabindex=\"-1\">Cancel</button>\r\n    </mat-dialog-actions>\r\n</div>"
            }] }
];
/** @nocollapse */
EditDialogComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];
if (false) {
    /** @type {?} */
    EditDialogComponent.prototype.datatransferFacade;
    /** @type {?} */
    EditDialogComponent.prototype.mode;
    /** @type {?} */
    EditDialogComponent.prototype.item;
    /** @type {?} */
    EditDialogComponent.prototype.itemPath;
    /** @type {?} */
    EditDialogComponent.prototype.itemName;
    /** @type {?} */
    EditDialogComponent.prototype.errorMessage;
    /** @type {?} */
    EditDialogComponent.prototype.editFormControl;
    /** @type {?} */
    EditDialogComponent.prototype.dialogRef;
    /** @type {?} */
    EditDialogComponent.prototype.data;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/facades/datatransfer.facade.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DatatransferFacade {
    /**
     * @param {?} logger
     * @param {?} zone
     * @param {?} store
     * @param {?} dateUtil
     * @param {?} paginationService
     * @param {?} exportService
     * @param {?} uploader
     * @param {?} downloader
     * @param {?} dialog
     */
    constructor(logger, zone, store, dateUtil, paginationService, exportService, uploader, downloader, dialog) {
        this.logger = logger;
        this.zone = zone;
        this.store = store;
        this.dateUtil = dateUtil;
        this.paginationService = paginationService;
        this.exportService = exportService;
        this.uploader = uploader;
        this.downloader = downloader;
        this.dialog = dialog;
        // Interval in milliseconds to calculate progress:
        this.progressInterval = 200;
        // Interval in milliseconds to calculate bitrate:
        this.bitrateInterval = 1000;
        this.uploadProgress = this.store.uploadProgress;
        this.downloadProgress = this.store.downloadProgress;
        this.init(this.uploader, this.uploadProgress);
        this.init(this.downloader, this.downloadProgress);
    }
    /**
     * @private
     * @param {?} datatransfer
     * @param {?} progressContainer
     * @return {?}
     */
    init(datatransfer, progressContainer) {
        datatransfer.on('itemAdded', (/**
         * @param {?} item
         * @return {?}
         */
        function (item) {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            that.zone.run((/**
             * @return {?}
             */
            () => {
                that.addItem(item);
            }));
        }).bind(this));
        datatransfer.on('zoneUpdated', (/**
         * @param {?} item
         * @param {?} status
         * @param {?=} message
         * @return {?}
         */
        function (item, status, message) {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            that.zone.run((/**
             * @return {?}
             */
            () => {
                // console.log(that.uploader.isWorking());
            }));
        }).bind(this));
        datatransfer.on('itemStatusChanged', (/**
         * @param {?} item
         * @param {?} status
         * @param {?=} message
         * @return {?}
         */
        function (item, status, message) {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            that.zone.run((/**
             * @return {?}
             */
            () => {
                that.changeItemStatus(item, status, message);
            }));
        }).bind(this));
        datatransfer.on('itemProgressUpdated', (/**
         * @param {?} item
         * @param {?} progress
         * @return {?}
         */
        function (item, progress) {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            that.zone.run((/**
             * @return {?}
             */
            () => {
                that.updateItemProgress(item, progress);
            }));
        }).bind(this));
        datatransfer.on('overallProgressUpdated', (/**
         * @param {?} transferType
         * @param {?} progress
         * @return {?}
         */
        function (transferType, progress) {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            that.zone.run((/**
             * @return {?}
             */
            () => {
                that.updateOverallProgress(progressContainer, transferType, progress);
            }));
        }).bind(this));
        datatransfer.on('overallSizeUpdated', (/**
         * @param {?} size
         * @return {?}
         */
        function (size) {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            that.zone.run((/**
             * @return {?}
             */
            () => {
                that.updateOverallSize(progressContainer, size);
            }));
        }).bind(this));
    }
    /**
     * @param {?} element
     * @param {?=} isDirectory
     * @return {?}
     */
    assignUploadBrowse(element, isDirectory = false) {
        this.uploader.assignBrowse(element, isDirectory);
    }
    /**
     * @param {?} element
     * @return {?}
     */
    assignUploadDrop(element) {
        this.uploader.assignDrop(element);
    }
    /**
     * @return {?}
     */
    openBrowseDialog() {
        /** @type {?} */
        const dialogRef = this.dialog.open(BrowseDialogComponent, {
            data: {
                datatransferFacade: this
            }
        });
    }
    /**
     * @param {?} item
     * @return {?}
     */
    openEditPathDialog(item) {
        /** @type {?} */
        const dialogRef = this.dialog.open(EditDialogComponent, {
            data: {
                datatransferFacade: this,
                mode: 'edit-path',
                item
            }
        });
    }
    /**
     * @param {?} item
     * @return {?}
     */
    openEditFilenameDialog(item) {
        /** @type {?} */
        const dialogRef = this.dialog.open(EditDialogComponent, {
            data: {
                datatransferFacade: this,
                mode: 'edit-filename',
                item
            }
        });
    }
    /**
     * @param {?} checked
     * @return {?}
     */
    toggleVisible(checked) {
        this.paginationService.paginatedItems.forEach((/**
         * @param {?} item
         * @param {?} index
         * @return {?}
         */
        (item, index) => {
            item.isSelected = checked;
        }));
    }
    /**
     * @return {?}
     */
    startAll() {
        this.store.getItems().forEach((/**
         * @param {?} item
         * @param {?} index
         * @return {?}
         */
        (item, index) => {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            if (item.transferType === TransferType.Upload && item.status === TransferStatus.Ready) {
                that.changeItemStatus(item, TransferStatus.Queued);
            }
        }));
        this.uploader.startAll();
    }
    /**
     * @return {?}
     */
    pauseAll() {
        this.store.getItems().forEach((/**
         * @param {?} item
         * @param {?} index
         * @return {?}
         */
        (item, index) => {
            item.preprocessContainer.pause(true);
        }));
        this.uploader.pauseAll();
        this.downloader.pauseAll();
    }
    /**
     * @return {?}
     */
    removeAll() {
        this.store.getItems().forEach((/**
         * @param {?} item
         * @param {?} index
         * @return {?}
         */
        (item, index) => {
            item.preprocessContainer.cancel(true);
        }));
        this.uploader.removeAll();
        this.downloader.removeAll();
        this.store.clear();
        this.uploadProgress.reset(0);
        this.paginationService.update(0);
        document.dispatchEvent(new CustomEvent(CustomEventTypeExtensions.toString(CustomEventType.ITEMS_CLEARED)));
    }
    /**
     * @return {?}
     */
    retryAll() {
        this.store.getByStatus(TransferStatus.Failed).forEach((/**
         * @param {?} item
         * @param {?} index
         * @return {?}
         */
        (item, index) => {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            that.retryItem(item);
        }));
    }
    /**
     * @return {?}
     */
    removeSelected() {
        /** @type {?} */
        const temp = this.store.getSelected().slice();
        temp.forEach((/**
         * @param {?} item
         * @param {?} index
         * @return {?}
         */
        (item, index) => {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            that.removeItem(item);
        }));
    }
    /**
     * @param {?} item
     * @return {?}
     */
    addItem(item) {
        if (!!item) {
            this.store.addItem(item);
            this.paginationService.update(this.store.count);
            document.dispatchEvent(new CustomEvent(CustomEventTypeExtensions.toString(CustomEventType.ITEM_ADDED), { detail: item }));
        }
    }
    /**
     * @param {?} item
     * @return {?}
     */
    removeItem(item) {
        if (!!item) {
            item.preprocessContainer.cancel(true);
            switch (item.transferType) {
                case TransferType.Upload:
                    this.uploader.removeItem(item);
                    break;
                case TransferType.Download:
                    this.downloader.removeItem(item);
                    break;
                default:
                    break;
            }
            this.store.removeById(item.id);
            this.paginationService.update(this.store.count);
            document.dispatchEvent(new CustomEvent(CustomEventTypeExtensions.toString(CustomEventType.ITEM_REMOVED), { detail: item }));
        }
    }
    /**
     * @param {?} item
     * @return {?}
     */
    retryItem(item) {
        if (!!item) {
            item.preprocessContainer.cancel(true);
            switch (item.transferType) {
                case TransferType.Upload:
                    this.uploader.retryItem(item);
                    break;
                case TransferType.Download:
                    this.downloader.retryItem(item);
                    break;
                default:
                    break;
            }
        }
    }
    /**
     * @param {?} item
     * @param {?} status
     * @param {?=} message
     * @return {?}
     */
    changeItemStatus(item, status, message) {
        if (!!item && !!status) {
            if (item.status !== status) {
                this.paginationService.setPageByItemId(item.id);
                item.status = status;
                if (!!message) {
                    item.message = message;
                }
                this.store.updateFailedCount();
                if (status === TransferStatus.Finished) {
                    document.dispatchEvent(new CustomEvent(CustomEventTypeExtensions.toString(CustomEventType.ITEM_COMPLETED), { detail: item }));
                }
            }
        }
    }
    /**
     * @param {?} item
     * @param {?} progress
     * @return {?}
     */
    updateItemProgress(item, progress) {
        if (!!item) {
            /** @type {?} */
            const now = this.dateUtil.now();
            /** @type {?} */
            const loaded = item.progressContainer.total * progress;
            item.progressContainer.updateBitrate(now, loaded, this.bitrateInterval);
            item.progressContainer.updateProgress(now, loaded, this.progressInterval);
        }
    }
    /**
     * @param {?} progressContainer
     * @param {?} transferType
     * @param {?} progress
     * @return {?}
     */
    updateOverallProgress(progressContainer, transferType, progress) {
        /** @type {?} */
        const now = this.dateUtil.now();
        /** @type {?} */
        const loaded = progressContainer.total * progress;
        // this.logger.log('total: ' + progressContainer.total + ' progress: ' + progress + ' loaded: ' + loaded);
        progressContainer.updateBitrate(now, loaded, this.bitrateInterval);
        progressContainer.updateProgress(now, loaded, this.progressInterval);
        if (progressContainer.total > 0 && loaded >= progressContainer.total) {
            switch (transferType) {
                case TransferType.Upload:
                    document.dispatchEvent(new CustomEvent(CustomEventTypeExtensions.toString(CustomEventType.UPLOAD_COMPLETED)));
                    break;
                case TransferType.Download:
                    document.dispatchEvent(new CustomEvent(CustomEventTypeExtensions.toString(CustomEventType.DOWNLOAD_COMPLETED)));
                    break;
                default:
                    break;
            }
        }
    }
    /**
     * @param {?} progressContainer
     * @param {?} size
     * @return {?}
     */
    updateOverallSize(progressContainer, size) {
        progressContainer.reset(size);
    }
    /**
     * @param {?} filename
     * @param {?} url
     * @param {?} sizeInBytes
     * @return {?}
     */
    download(filename, url, sizeInBytes) {
        this.downloader.download(filename, url, sizeInBytes);
    }
    /**
     * @param {?} exportType
     * @return {?}
     */
    export(exportType) {
        this.exportService.export(exportType);
    }
    /**
     * @param {?} status
     * @return {?}
     */
    getStatusClass(status) {
        switch (status) {
            case TransferStatus.Ready:
                return 'add_circle_outline';
            case TransferStatus.Uploading:
                return 'arrow_upward';
            case TransferStatus.Downloading:
                return 'arrow_downward';
            case TransferStatus.Failed:
                return 'error_outline';
            case TransferStatus.Queued:
            case TransferStatus.Preprocessing:
                return 'schedule';
            case TransferStatus.Finished:
                return 'done_all';
            default:
                return '';
        }
    }
    /**
     * @return {?}
     */
    showStartButton() {
        return this.store.count > 0 && !this.uploader.isWorking() && !this.downloader.isWorking();
    }
    /**
     * @return {?}
     */
    showPauseButton() {
        return this.uploader.isWorking();
    }
    /**
     * @return {?}
     */
    showRemoveButton() {
        return this.store.count > 0;
    }
    /**
     * @return {?}
     */
    showRetryButton() {
        return this.store.failedCount > 0 && !this.uploader.isWorking() && !this.downloader.isWorking();
    }
    /**
     * @param {?} item
     * @return {?}
     */
    showRetryButtonByItem(item) {
        return item.status === TransferStatus.Failed;
    }
    /**
     * @return {?}
     */
    showExportButton() {
        return this.store.count > 0;
    }
    /**
     * @return {?}
     */
    showPreprocessingCheckbox() {
        return this.store.count > 0 && ConfigService.settings.core.preprocessHashEnabled;
    }
    /**
     * @return {?}
     */
    showPreprocessingTooltip() {
        return this.showPreprocessingCheckbox() && !!ConfigService.settings.core.preprocessHashTooltipContent;
    }
    /**
     * @param {?} item
     * @return {?}
     */
    showSpinner(item) {
        return item.preprocessContainer.percent > 0 && item.status === TransferStatus.Preprocessing;
    }
    /**
     * @param {?} item
     * @return {?}
     */
    showProgressbar(item) {
        return item.progressContainer.percent > 0 &&
            (item.status === TransferStatus.Uploading || item.status === TransferStatus.Downloading);
    }
    /**
     * @param {?} items
     * @param {?} index
     * @return {?}
     */
    showPath(items, index) {
        if (index > 0 && items.length > index) {
            /** @type {?} */
            const currentPath = items[index].path;
            // don't show if previous path is same as current
            return items[index - 1].path !== currentPath;
        }
        return true;
    }
    /**
     * @param {?} item
     * @return {?}
     */
    showEditDialog(item) {
        /** @type {?} */
        let result = false;
        if (item) {
            switch (item.transferType) {
                case TransferType.Upload:
                    if (item.status === TransferStatus.Ready) {
                        result = true;
                    }
                    break;
                default:
                    break;
            }
        }
        return result;
    }
    /**
     * @param {?} item
     * @param {?} oldPath
     * @param {?} newPath
     * @return {?}
     */
    editPath(item, oldPath, newPath) {
        switch (item.transferType) {
            case TransferType.Upload:
                // replace all \ with /
                /** @type {?} */
                let cleanedPath = newPath.replace(/\\/g, '/');
                // replace repeated / with one
                cleanedPath = cleanedPath.replace(/\/+/g, '/');
                if (cleanedPath.startsWith('/')) {
                    cleanedPath = cleanedPath.slice(1);
                }
                if (cleanedPath && !cleanedPath.endsWith('/')) {
                    cleanedPath += '/';
                }
                this.uploader.editPath(oldPath, cleanedPath);
                break;
            default:
                break;
        }
    }
    /**
     * @param {?} item
     * @param {?} name
     * @return {?}
     */
    editFilename(item, name) {
        switch (item.transferType) {
            case TransferType.Upload:
                this.uploader.editFilename(item, name);
                break;
            default:
                break;
        }
    }
    /**
     * @param {?} item
     * @return {?}
     */
    parseMessage(item) {
        if (ConfigService.settings.core.parseMessageCallback instanceof Function) {
            return ConfigService.settings.core.parseMessageCallback(item.message);
        }
        else {
            return undefined;
        }
    }
}
if (false) {
    /**
     * @type {?}
     * @private
     */
    DatatransferFacade.prototype.uploadProgress;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacade.prototype.downloadProgress;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacade.prototype.progressInterval;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacade.prototype.bitrateInterval;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacade.prototype.logger;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacade.prototype.zone;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacade.prototype.store;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacade.prototype.dateUtil;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacade.prototype.paginationService;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacade.prototype.exportService;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacade.prototype.uploader;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacade.prototype.downloader;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacade.prototype.dialog;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/models/pagination-container.model.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IPaginationContainer() { }
if (false) {
    /** @type {?} */
    IPaginationContainer.prototype.pages;
    /** @type {?} */
    IPaginationContainer.prototype.page;
    /** @type {?} */
    IPaginationContainer.prototype.rpp;
    /** @type {?} */
    IPaginationContainer.prototype.total;
    /** @type {?} */
    IPaginationContainer.prototype.rppOptions;
}
class PaginationContainer {
    constructor() {
        this.pages = [];
        this.page = 1;
        this.rpp = 5;
        this.total = 0;
    }
}
if (false) {
    /** @type {?} */
    PaginationContainer.prototype.pages;
    /** @type {?} */
    PaginationContainer.prototype.page;
    /** @type {?} */
    PaginationContainer.prototype.rpp;
    /** @type {?} */
    PaginationContainer.prototype.total;
    /** @type {?} */
    PaginationContainer.prototype.rppOptions;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/utils/date.util.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DateUtil {
    /**
     * @return {?}
     */
    now() {
        return ((Date.now) ? Date.now() : (new Date()).getTime());
    }
    /**
     * @param {?} seconds
     * @return {?}
     */
    format(seconds) {
        /** @type {?} */
        let date = new Date(seconds * 1000);
        if (isNaN(date.getTime())) {
            return undefined;
        }
        else {
            return ('0' + date.getUTCHours()).slice(-2) + ':' +
                ('0' + date.getUTCMinutes()).slice(-2) + ':' +
                ('0' + date.getUTCSeconds()).slice(-2);
        }
    }
}
DateUtil.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/enums/decimal-byte-unit.enum.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
const DecimalByteUnit = {
    /**
     * Byte (B)
     * 1 Byte
     */
    Byte: 0,
    /**
     * Kilobyte (kB)
     * 10^3 Byte = 1.000 Byte
     */
    KB: 1,
    /**
     * Megabyte (MB)
     * 10^6 Byte = 1.000.000 Byte
     */
    MB: 2,
    /**
     * Gigabyte (GB)
     * 10^9 Byte = 1.000.000.000 Byte
     */
    GB: 3,
    /**
     * Terabyte (TB)
     * 10^12 Byte = 1.000.000.000.000 Byte
     */
    TB: 4,
    /**
     * Petabyte (PB)
     * 10^15 Byte = 1.000.000.000.000.000 Byte
     */
    PB: 5,
};
DecimalByteUnit[DecimalByteUnit.Byte] = 'Byte';
DecimalByteUnit[DecimalByteUnit.KB] = 'KB';
DecimalByteUnit[DecimalByteUnit.MB] = 'MB';
DecimalByteUnit[DecimalByteUnit.GB] = 'GB';
DecimalByteUnit[DecimalByteUnit.TB] = 'TB';
DecimalByteUnit[DecimalByteUnit.PB] = 'PB';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/extensions/enum.extension.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// @dynamic
class EnumExtension {
    /**
     * @template T
     * @param {?} e
     * @return {?}
     */
    static getNamesAndValues(e) {
        return this.getNames(e).map((/**
         * @param {?} n
         * @return {?}
         */
        n => ({ name: n, value: (/** @type {?} */ (e[n])) })));
    }
    /**
     * @param {?} e
     * @return {?}
     */
    static getNames(e) {
        return (/** @type {?} */ (this.getObjValues(e).filter((/**
         * @param {?} v
         * @return {?}
         */
        v => typeof v === 'string'))));
    }
    /**
     * @template T
     * @param {?} e
     * @return {?}
     */
    static getValues(e) {
        return (/** @type {?} */ (this.getObjValues(e).filter((/**
         * @param {?} v
         * @return {?}
         */
        v => typeof v === 'number'))));
    }
    /**
     * @private
     * @param {?} e
     * @return {?}
     */
    static getObjValues(e) {
        return Object.keys(e).map((/**
         * @param {?} k
         * @return {?}
         */
        k => e[k]));
    }
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/utils/decimal-byte-unit.util.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DecimalByteUnitUtil {
    constructor() {
        this.C_KB = Math.pow(10, 3);
        this.C_MB = Math.pow(10, 6);
        this.C_GB = Math.pow(10, 9);
        this.C_TB = Math.pow(10, 12);
        this.C_PB = Math.pow(10, 15);
        this.MAX = Number.MAX_VALUE;
        this.byteUnits = EnumExtension.getNames(DecimalByteUnit);
    }
    /**
     * @private
     * @param {?} number
     * @param {?} multiplier
     * @return {?}
     */
    multiply(number, multiplier) {
        /** @type {?} */
        const limit = this.MAX / multiplier;
        if (number > limit) {
            return Number.MAX_VALUE;
        }
        if (number < -limit) {
            return Number.MIN_VALUE;
        }
        return number * multiplier;
    }
    /**
     * @param {?} number
     * @param {?} fromUnit
     * @param {?} toUnit
     * @return {?}
     */
    convert(number, fromUnit, toUnit) {
        /** @type {?} */
        const bytes = this.toBytes(number, fromUnit);
        switch (toUnit) {
            case DecimalByteUnit.Byte:
                return bytes;
            case DecimalByteUnit.KB:
                return bytes / this.C_KB;
            case DecimalByteUnit.MB:
                return bytes / this.C_MB;
            case DecimalByteUnit.GB:
                return bytes / this.C_GB;
            case DecimalByteUnit.TB:
                return bytes / this.C_TB;
            case DecimalByteUnit.PB:
                return bytes / this.C_PB;
        }
        return number;
    }
    /**
     * @param {?} number
     * @param {?} fromUnit
     * @return {?}
     */
    toBytes(number, fromUnit) {
        switch (fromUnit) {
            case DecimalByteUnit.Byte:
                return number;
            case DecimalByteUnit.KB:
                return this.multiply(number, this.C_KB);
            case DecimalByteUnit.MB:
                return this.multiply(number, this.C_MB);
            case DecimalByteUnit.GB:
                return this.multiply(number, this.C_GB);
            case DecimalByteUnit.TB:
                return this.multiply(number, this.C_TB);
            case DecimalByteUnit.PB:
                return this.multiply(number, this.C_PB);
        }
        return number;
    }
    /**
     * @param {?} number
     * @param {?} fromUnit
     * @return {?}
     */
    format(number, fromUnit) {
        /** @type {?} */
        let result;
        result = [DecimalByteUnit.Byte, this.toBytes(number, fromUnit)];
        for (const currentUnit of this.byteUnits) {
            if (Math.abs(result[1]) < 1000) {
                result[0] = DecimalByteUnit[currentUnit];
                break;
            }
            else {
                result[1] /= 1000;
            }
        }
        result[1] = Number(result[1].toFixed(2));
        return result;
    }
}
DecimalByteUnitUtil.decorators = [
    { type: Injectable }
];
if (false) {
    /** @type {?} */
    DecimalByteUnitUtil.prototype.C_KB;
    /** @type {?} */
    DecimalByteUnitUtil.prototype.C_MB;
    /** @type {?} */
    DecimalByteUnitUtil.prototype.C_GB;
    /** @type {?} */
    DecimalByteUnitUtil.prototype.C_TB;
    /** @type {?} */
    DecimalByteUnitUtil.prototype.C_PB;
    /** @type {?} */
    DecimalByteUnitUtil.prototype.MAX;
    /** @type {?} */
    DecimalByteUnitUtil.prototype.byteUnits;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/models/size-container.model.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function ISizeContainer() { }
if (false) {
    /** @type {?} */
    ISizeContainer.prototype.displayUnit;
    /** @type {?} */
    ISizeContainer.prototype.displaySize;
    /** @type {?} */
    ISizeContainer.prototype.decimalByteUnit;
    /** @type {?} */
    ISizeContainer.prototype.decimalByteUnitSize;
    /**
     * @param {?=} init
     * @return {?}
     */
    ISizeContainer.prototype.update = function (init) { };
    /**
     * @param {?} decimalByteUnit
     * @param {?} decimalByteUnitSize
     * @return {?}
     */
    ISizeContainer.prototype.updateDecimal = function (decimalByteUnit, decimalByteUnitSize) { };
}
class SizeContainer {
    /**
     * @param {?=} init
     */
    constructor(init) {
        this.decimalByteUnit = DecimalByteUnit.MB;
        this.decimalByteUnitSize = 0;
        /** @type {?} */
        let injector = ReflectiveInjector.resolveAndCreate([DecimalByteUnitUtil]);
        this.decimalByteUnitUtil = injector.get(DecimalByteUnitUtil);
        this.update(init);
    }
    /**
     * @param {?=} init
     * @return {?}
     */
    update(init) {
        if (!!this.decimalByteUnitUtil && !!init && !!init.decimalByteUnitSize) {
            this.updateDecimal(init.decimalByteUnit, init.decimalByteUnitSize);
        }
    }
    /**
     * @param {?} decimalByteUnit
     * @param {?} decimalByteUnitSize
     * @return {?}
     */
    updateDecimal(decimalByteUnit, decimalByteUnitSize) {
        /** @type {?} */
        let convertResult = this.decimalByteUnitUtil.format(decimalByteUnitSize, decimalByteUnit);
        this.decimalByteUnit = convertResult[0];
        this.decimalByteUnitSize = convertResult[1];
        this.displayUnit = DecimalByteUnit[this.decimalByteUnit];
        this.displaySize = !!this.decimalByteUnitSize ? this.decimalByteUnitSize : 0;
    }
}
if (false) {
    /**
     * @type {?}
     * @private
     */
    SizeContainer.prototype.decimalByteUnitUtil;
    /** @type {?} */
    SizeContainer.prototype.displayUnit;
    /** @type {?} */
    SizeContainer.prototype.displaySize;
    /** @type {?} */
    SizeContainer.prototype.decimalByteUnit;
    /** @type {?} */
    SizeContainer.prototype.decimalByteUnitSize;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/models/progress-container.model.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IProgressContainer() { }
if (false) {
    /** @type {?} */
    IProgressContainer.prototype.total;
    /** @type {?} */
    IProgressContainer.prototype.progressTimestamp;
    /** @type {?} */
    IProgressContainer.prototype.bitrateTimestamp;
    /** @type {?} */
    IProgressContainer.prototype.bitrate;
    /** @type {?} */
    IProgressContainer.prototype.percent;
    /** @type {?} */
    IProgressContainer.prototype.displayBitrate;
    /** @type {?} */
    IProgressContainer.prototype.displayTimeLeft;
    /** @type {?} */
    IProgressContainer.prototype.loadedSizeContainer;
    /** @type {?} */
    IProgressContainer.prototype.totalSizeContainer;
    /**
     * @param {?} total
     * @return {?}
     */
    IProgressContainer.prototype.reset = function (total) { };
    /**
     * @param {?} now
     * @param {?} loaded
     * @param {?} interval
     * @return {?}
     */
    IProgressContainer.prototype.updateProgress = function (now, loaded, interval) { };
    /**
     * @param {?} now
     * @param {?} loaded
     * @param {?} interval
     * @return {?}
     */
    IProgressContainer.prototype.updateBitrate = function (now, loaded, interval) { };
}
class ProgressContainer {
    /**
     * @param {?} total
     */
    constructor(total) {
        /** @type {?} */
        const injector = ReflectiveInjector.resolveAndCreate([DateUtil]);
        this.dateUtil = injector.get(DateUtil);
        this.bitrateSizeContainer = new SizeContainer();
        this.loadedSizeContainer = new SizeContainer();
        this.totalSizeContainer = new SizeContainer();
        this.reset(total);
    }
    /**
     * @param {?} total
     * @return {?}
     */
    reset(total) {
        this.progressTimestamp = this.dateUtil.now();
        this.bitrateTimestamp = this.dateUtil.now();
        this.loaded = 0;
        this.bitrate = 0;
        this.percent = 0;
        this.total = total;
        this.displayBitrate = undefined;
        this.displayTimeLeft = undefined;
        this.bitrateSizeContainer.updateDecimal(DecimalByteUnit.Byte, this.bitrate);
        this.loadedSizeContainer.updateDecimal(DecimalByteUnit.Byte, this.loaded);
        this.totalSizeContainer.updateDecimal(DecimalByteUnit.Byte, this.total);
    }
    /**
     * @param {?} now
     * @param {?} loaded
     * @param {?} interval
     * @return {?}
     */
    updateProgress(now, loaded, interval) {
        /** @type {?} */
        const timeDiff = now - this.progressTimestamp;
        // console.log('loaded: ' + loaded + ' total: ' + this.total);
        if (!this.percent || timeDiff > interval) {
            this.percent = Number((loaded / this.total * 100).toFixed(2));
            this.loaded = loaded;
            this.loadedSizeContainer.updateDecimal(DecimalByteUnit.Byte, this.loaded);
            this.progressTimestamp = now;
            if (this.bitrate > 0) {
                this.displayTimeLeft = this.dateUtil.format((this.total - this.loaded) * 8 / this.bitrate);
            }
            else {
                this.displayTimeLeft = this.dateUtil.format(0);
            }
        }
        else if (loaded >= this.total) {
            this.percent = 100;
            this.loaded = this.total;
        }
    }
    /**
     * @param {?} now
     * @param {?} loaded
     * @param {?} interval
     * @return {?}
     */
    updateBitrate(now, loaded, interval) {
        /** @type {?} */
        const timeDiff = now - this.bitrateTimestamp;
        if (!this.bitrate || timeDiff > interval) {
            this.bitrate = (loaded - this.loaded) * (1000 / timeDiff) * 8;
            if (this.bitrate === Number.POSITIVE_INFINITY || this.bitrate === Number.NEGATIVE_INFINITY) {
                this.bitrate = 0;
            }
            this.bitrateSizeContainer.updateDecimal(DecimalByteUnit.Byte, this.bitrate / 8);
            this.displayBitrate = this.bitrateSizeContainer.displaySize + ' ' + this.bitrateSizeContainer.displayUnit + '/s';
            this.bitrateTimestamp = now;
        }
    }
}
if (false) {
    /**
     * @type {?}
     * @private
     */
    ProgressContainer.prototype.dateUtil;
    /**
     * @type {?}
     * @private
     */
    ProgressContainer.prototype.loaded;
    /**
     * @type {?}
     * @private
     */
    ProgressContainer.prototype.bitrateSizeContainer;
    /** @type {?} */
    ProgressContainer.prototype.total;
    /** @type {?} */
    ProgressContainer.prototype.progressTimestamp;
    /** @type {?} */
    ProgressContainer.prototype.bitrateTimestamp;
    /** @type {?} */
    ProgressContainer.prototype.bitrate;
    /** @type {?} */
    ProgressContainer.prototype.percent;
    /** @type {?} */
    ProgressContainer.prototype.displayBitrate;
    /** @type {?} */
    ProgressContainer.prototype.displayTimeLeft;
    /** @type {?} */
    ProgressContainer.prototype.loadedSizeContainer;
    /** @type {?} */
    ProgressContainer.prototype.totalSizeContainer;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/stores/datatransfer.store.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DatatransferStore {
    constructor() {
        this.items = [];
        this.count = 0;
        this.failedCount = 0;
        this.uploadProgress = new ProgressContainer(0);
        this.downloadProgress = new ProgressContainer(0);
    }
    /**
     * @private
     * @return {?}
     */
    updateCount() {
        this.count = this.items.length;
    }
    /**
     * @return {?}
     */
    updateFailedCount() {
        this.failedCount = this.getByStatus(TransferStatus.Failed).length;
    }
    /**
     * @return {?}
     */
    getItems() {
        return this.items;
    }
    /**
     * @return {?}
     */
    getSelected() {
        return this.items.filter((/**
         * @param {?} item
         * @return {?}
         */
        (item) => item.isSelected === true));
    }
    /**
     * @param {?} id
     * @return {?}
     */
    getById(id) {
        return this.items.find((/**
         * @param {?} item
         * @return {?}
         */
        (item) => item.id === id));
    }
    /**
     * @param {?} id
     * @return {?}
     */
    getIndexById(id) {
        return this.items.findIndex((/**
         * @param {?} i
         * @return {?}
         */
        i => i.id === id));
    }
    /**
     * @return {?}
     */
    clear() {
        this.items.length = 0;
        this.updateCount();
        this.updateFailedCount();
    }
    /**
     * @param {?} item
     * @return {?}
     */
    addItem(item) {
        this.items.push(item);
        this.updateCount();
    }
    /**
     * @param {?} id
     * @return {?}
     */
    removeById(id) {
        /** @type {?} */
        const index = this.getIndexById(id);
        if (index > -1) {
            this.items.splice(index, 1);
            this.updateCount();
        }
    }
    /**
     * @param {?} status
     * @return {?}
     */
    getByStatus(status) {
        return this.items.filter((/**
         * @param {?} item
         * @return {?}
         */
        (item) => item.status === status));
    }
}
DatatransferStore.decorators = [
    { type: Injectable }
];
/** @nocollapse */
DatatransferStore.ctorParameters = () => [];
if (false) {
    /**
     * @type {?}
     * @private
     */
    DatatransferStore.prototype.items;
    /** @type {?} */
    DatatransferStore.prototype.count;
    /** @type {?} */
    DatatransferStore.prototype.failedCount;
    /** @type {?} */
    DatatransferStore.prototype.uploadProgress;
    /** @type {?} */
    DatatransferStore.prototype.downloadProgress;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/services/pagination.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PaginationService {
    /**
     * @param {?} datatransferStore
     */
    constructor(datatransferStore) {
        this.datatransferStore = datatransferStore;
        this.paginatedItems = [];
        this.pagination = new PaginationContainer();
    }
    /**
     * @param {?} rppOptions
     * @return {?}
     */
    setRppOptions(rppOptions) {
        this.pagination.rppOptions = rppOptions;
        this.setPaginationContainer();
    }
    /**
     * @param {?} total
     * @return {?}
     */
    update(total) {
        if (total <= 0) {
            this.paginatedItems.length = 0;
        }
        this.pagination.total = total;
        this.setPaginationContainer();
    }
    /**
     * @return {?}
     */
    setPaginationContainer() {
        /** @type {?} */
        const pageCount = this.pageCount();
        if (this.pagination.pages.length > pageCount) {
            this.pagination.pages.splice(pageCount);
        }
        else {
            for (let i = this.pagination.pages.length; i < pageCount; i++) {
                this.pagination.pages.push(i + 1);
            }
        }
        if (!this.pagination.pages.includes(this.pagination.page)) {
            this.pagination.page = 1;
        }
        if (!!this.pagination.rppOptions && this.pagination.rppOptions.length > 0
            && !this.pagination.rppOptions.includes(this.pagination.rpp)) {
            this.pagination.rpp = this.pagination.rppOptions[0];
        }
        this.onPaginationChange();
    }
    /**
     * @return {?}
     */
    max() {
        return this.hasNext() ? this.pagination.page * this.pagination.rpp : this.pagination.total;
    }
    /**
     * @return {?}
     */
    min() {
        return this.pagination.total > 0 ? this.pagination.page * this.pagination.rpp - this.pagination.rpp + 1 : 0;
    }
    /**
     * @return {?}
     */
    first() {
        this.pagination.page = 1;
        this.onPaginationChange();
    }
    /**
     * @return {?}
     */
    last() {
        this.pagination.page = this.pageCount();
        this.onPaginationChange();
    }
    /**
     * @return {?}
     */
    hasNext() {
        return this.pagination.page * this.pagination.rpp < this.pagination.total;
    }
    /**
     * @return {?}
     */
    hasPrevious() {
        return this.pagination.page > 1;
    }
    /**
     * @return {?}
     */
    moveNext() {
        this.pagination.page++;
        this.onPaginationChange();
    }
    /**
     * @return {?}
     */
    movePrevious() {
        this.pagination.page--;
        this.onPaginationChange();
    }
    /**
     * @param {?} page
     * @return {?}
     */
    setPage(page) {
        this.pagination.page = page;
        this.onPageChange();
    }
    /**
     * @return {?}
     */
    onPageChange() {
        this.setPaginationContainer();
        this.onPaginationChange();
    }
    /**
     * @return {?}
     */
    onRppChange() {
        this.setPaginationContainer();
        this.pagination.page = 1;
        this.onPaginationChange();
    }
    /**
     * @return {?}
     */
    onPaginationChange() {
        /** @type {?} */
        const startIndex = (this.pagination.page - 1) * this.pagination.rpp;
        /** @type {?} */
        const endIndex = Math.min(startIndex + this.pagination.rpp, this.pagination.total);
        this.paginatedItems = this.datatransferStore.getItems().slice(startIndex, endIndex);
    }
    /**
     * @return {?}
     */
    pageCount() {
        return this.pagination.total > 0 ? Math.ceil(this.pagination.total / (this.pagination.rpp > 0 ? this.pagination.rpp : 1)) : 1;
    }
    /**
     * @param {?} id
     * @return {?}
     */
    getPageByItemId(id) {
        /** @type {?} */
        const index = this.datatransferStore.getIndexById(id);
        if (index > -1) {
            return Math.ceil((index + 1) / this.pagination.rpp);
        }
    }
    /**
     * @param {?} id
     * @return {?}
     */
    setPageByItemId(id) {
        /** @type {?} */
        const page = this.getPageByItemId(id);
        if (this.pagination.page !== page) {
            this.setPage(page);
        }
    }
}
PaginationService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
PaginationService.ctorParameters = () => [
    { type: DatatransferStore }
];
if (false) {
    /** @type {?} */
    PaginationService.prototype.pagination;
    /** @type {?} */
    PaginationService.prototype.paginatedItems;
    /**
     * @type {?}
     * @private
     */
    PaginationService.prototype.datatransferStore;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/main.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MainComponent {
    /**
     * @param {?} datatransferStore
     * @param {?} paginationService
     */
    constructor(datatransferStore, paginationService) {
        this.datatransferStore = datatransferStore;
        this.paginationService = paginationService;
        this.config = ConfigService.settings;
        this.uploadProgress = this.datatransferStore.uploadProgress;
        this.downloadProgress = this.datatransferStore.downloadProgress;
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.init();
    }
    /**
     * @private
     * @return {?}
     */
    init() {
        if (this.config.core.showUploadDropzone) {
            /** @type {?} */
            const dropzoneElement = document.getElementById('amd-dropzone-component');
            if (dropzoneElement) {
                dropzoneElement.addEventListener('click', this.datatransferFacade.openBrowseDialog.bind(this.datatransferFacade), false);
                this.datatransferFacade.assignUploadDrop(dropzoneElement);
            }
        }
        else {
            if (typeof this.config.core.uploadBrowseElementId !== 'undefined') {
                /** @type {?} */
                const uploadBrowseElement = document.getElementById(this.config.core.uploadBrowseElementId);
                if (uploadBrowseElement) {
                    uploadBrowseElement.addEventListener('click', this.datatransferFacade.openBrowseDialog.bind(this.datatransferFacade), false);
                }
            }
            if (typeof this.config.core.uploadDropElementId !== 'undefined') {
                /** @type {?} */
                const uploadDropElement = document.getElementById(this.config.core.uploadDropElementId);
                if (uploadDropElement) {
                    this.datatransferFacade.assignUploadDrop(uploadDropElement);
                }
            }
        }
    }
}
MainComponent.decorators = [
    { type: Component, args: [{
                // tslint:disable-next-line:component-selector
                selector: 'amd-main',
                template: "<div class=\"amd-font\">\r\n    <div *ngIf=\"config.core.showUploadDropzone\">\r\n        <amd-dropzone></amd-dropzone>\r\n    </div>\r\n\r\n    <div fxLayout=\"row\" fxLayout.lt-sm=\"column\" style=\"margin-bottom: 10px\">\r\n        <div fxFlex>\r\n            <button class=\"amd-mr-1\" mat-raised-button *ngIf=\"datatransferFacade.showStartButton()\"\r\n                (click)=\"datatransferFacade.startAll()\">\r\n                <mat-icon>play_arrow</mat-icon> Start\r\n            </button>\r\n            <button class=\"amd-mr-1\" mat-raised-button *ngIf=\"datatransferFacade.showPauseButton()\"\r\n                (click)=\"datatransferFacade.pauseAll()\">\r\n                <mat-icon>pause</mat-icon> Pause\r\n            </button>\r\n            <button class=\"amd-mr-1\" mat-raised-button *ngIf=\"datatransferFacade.showRemoveButton()\"\r\n                (click)=\"datatransferFacade.removeAll()\">\r\n                <mat-icon>close</mat-icon> Remove all\r\n            </button>\r\n            <button class=\"amd-mr-1\" mat-raised-button *ngIf=\"datatransferFacade.showRetryButton()\"\r\n                (click)=\"datatransferFacade.retryAll()\">\r\n                <mat-icon>refresh</mat-icon> Retry ({{datatransferStore.failedCount}})\r\n            </button>\r\n            <mat-menu #exportMenu=\"matMenu\">\r\n                <button mat-menu-item (click)=\"datatransferFacade.export('CSV')\">\r\n                    <span>CSV</span>\r\n                </button>\r\n                <button mat-menu-item (click)=\"datatransferFacade.export('JSON')\">\r\n                    <span>JSON</span>\r\n                </button>\r\n            </mat-menu>\r\n            <button mat-raised-button *ngIf=\"datatransferFacade.showExportButton()\" [matMenuTriggerFor]=\"exportMenu\">\r\n                Export\r\n                <mat-icon>expand_more</mat-icon>\r\n            </button>\r\n            <mat-checkbox *ngIf=\"datatransferFacade.showPreprocessingCheckbox()\"\r\n                [(ngModel)]=\"config.core.preprocessHashChecked\" style=\"margin-left: 10px;\">\r\n                Preprocessing <span *ngIf=\"datatransferFacade.showPreprocessingTooltip()\"\r\n                    class=\"amd-vertical-align-middle\" [matTooltip]=\"config.core.preprocessHashTooltipContent\"\r\n                    matTooltipPosition=\"right\">\r\n                    <mat-icon>info_outline</mat-icon>\r\n                </span>\r\n            </mat-checkbox>\r\n        </div>\r\n        <div fxFlex=\"70px\" fxFlex.lt-sm=\"0px\">\r\n        </div>\r\n        <div fxFlex>\r\n            <div *ngIf=\"uploadProgress.percent > 0\">\r\n                <amd-progress [progressContainer]=\"uploadProgress\"></amd-progress>\r\n            </div>\r\n            <div *ngIf=\"downloadProgress.percent > 0\">\r\n                <amd-progress [progressContainer]=\"downloadProgress\"></amd-progress>\r\n            </div>\r\n        </div>\r\n    </div>\r\n\r\n    <div class=\"amd-container\">\r\n        <div fxLayout=\"row\" class=\"amd-container-header\" style=\"align-items: center;\">\r\n            <div fxFlex=\"40px\">\r\n                <mat-checkbox (change)=\"datatransferFacade.toggleVisible($event.checked)\"></mat-checkbox>\r\n            </div>\r\n            <div fxFlex=\"50%\" fxFlex.lt-sm=\"100%\">\r\n                Filename\r\n            </div>\r\n            <div fxFlex=\"50%\" style=\"padding-left: 40px;\" fxHide.lt-sm>\r\n                Progress\r\n            </div>\r\n            <div fxFlex=\"20px\">\r\n                <mat-menu #batchItemMenu=\"matMenu\">\r\n                    <button mat-menu-item (click)=\"datatransferFacade.removeSelected()\">\r\n                        <mat-icon>close</mat-icon>\r\n                        <span>Remove</span>\r\n                    </button>\r\n                </mat-menu>\r\n                <button mat-icon-button [matMenuTriggerFor]=\"batchItemMenu\">\r\n                    <mat-icon>more_vert</mat-icon>\r\n                </button>\r\n            </div>\r\n        </div>\r\n        <ng-template ngFor let-item [ngForOf]=\"paginationService.paginatedItems\" let-i=\"index\">\r\n            <div *ngIf=\"datatransferFacade.showPath(paginationService.paginatedItems, i)\">\r\n                <div fxLayout=\"row\" class=\"amd-container-headline\">\r\n                    <div fxFlex class=\"amd-container-headline-item\">\r\n                        <div class=\"amd-container-headline-item-entry\">\r\n                            <div fxFlex=\"40px\">\r\n                                <mat-icon>folder_open</mat-icon>\r\n                            </div>\r\n                            <div fxFlex>\r\n                                <span>\r\n                                    <b>{{item.displayPath}}</b>\r\n                                </span>\r\n                                <button mat-icon-button (click)=\"datatransferFacade.openEditPathDialog(item)\"\r\n                                    *ngIf=\"datatransferFacade.showEditDialog(item)\">\r\n                                    <mat-icon aria-label=\"Edit path\">edit</mat-icon>\r\n                                </button>\r\n                            </div>\r\n                        </div>\r\n                    </div>\r\n                </div>\r\n            </div>\r\n            <div fxLayout=\"row\" fxLayout.lt-sm=\"column\" class=\"amd-container-row\"\r\n                [ngClass]=\"{'selected': item.isSelected}\">\r\n                <div fxFlex class=\"amd-container-row-item\">\r\n                    <div class=\"amd-container-row-item-entry\">\r\n                        <div fxFlex=\"40px\">\r\n                            <mat-checkbox [(ngModel)]=\"item.isSelected\"></mat-checkbox>\r\n                        </div>\r\n                        <div fxFlex=\"100%\">\r\n                            <div matTooltip=\"{{item.name}}\" matTooltipPosition=\"above\">\r\n                                <span>{{item.name}}</span>\r\n                                <button mat-icon-button (click)=\"datatransferFacade.openEditFilenameDialog(item)\"\r\n                                    *ngIf=\"datatransferFacade.showEditDialog(item)\">\r\n                                    <mat-icon aria-label=\"Edit filename\">edit</mat-icon>\r\n                                </button>\r\n                            </div>\r\n                        </div>\r\n                    </div>\r\n                </div>\r\n                <div fxFlex class=\"amd-container-row-item\">\r\n                    <div class=\"amd-container-row-item-entry\">\r\n                        <div fxFlex=\"40px\" matTooltip=\"{{item.preprocessContainer.percent}}%\"\r\n                            *ngIf=\"datatransferFacade.showSpinner(item); else showStatusClass\">\r\n                            <mat-progress-spinner *ngIf=\"item.preprocessContainer.percent > 0\" [diameter]=\"20\"\r\n                                mode=\"determinate\" [value]=\"item.preprocessContainer.percent\"></mat-progress-spinner>\r\n                        </div>\r\n                        <ng-template #showStatusClass>\r\n                            <div fxFlex=\"40px\">\r\n                                <mat-icon>{{datatransferFacade.getStatusClass(item.status)}}</mat-icon>\r\n                            </div>\r\n                        </ng-template>\r\n                        <div fxFlex=\"100%\">\r\n                            <div *ngIf=\"datatransferFacade.showProgressbar(item); else showStatusBlock\">\r\n                                <div class=\"amd-container-row-item-entry-stats\">\r\n                                    <div fxFlex=\"25%\" fxFlex.lt-md=\"50%\">\r\n                                        {{item.progressContainer.displayBitrate}}\r\n                                    </div>\r\n                                    <div fxFlex=\"25%\" fxHide.lt-md style=\"text-align: center\">\r\n                                        {{item.progressContainer.displayTimeLeft}}\r\n                                    </div>\r\n                                    <div fxFlex=\"25%\" fxHide.lt-md style=\"text-align: center\">\r\n                                        {{item.progressContainer.percent}}%\r\n                                    </div>\r\n                                    <div fxFlex=\"25%\" fxFlex.lt-md=\"50%\" style=\"text-align: right\">\r\n                                        {{item.progressContainer.loadedSizeContainer.displaySize}} /\r\n                                        {{item.sizeContainer.displaySize}}\r\n                                        {{item.sizeContainer.displayUnit}}\r\n                                    </div>\r\n                                </div>\r\n                                <mat-progress-bar *ngIf=\"item.progressContainer.total > 0\" color=\"primary\"\r\n                                    mode=\"determinate\" [value]=\"item.progressContainer.percent\">\r\n                                </mat-progress-bar>\r\n                            </div>\r\n                            <ng-template #showStatusBlock>\r\n                                {{item.getStatusName()}} ({{item.sizeContainer.displaySize}}\r\n                                {{item.sizeContainer.displayUnit}})\r\n                                <div *ngIf=\"!!item.message\">\r\n                                    <small>{{datatransferFacade.parseMessage(item)}}</small>\r\n                                </div>\r\n                            </ng-template>\r\n                        </div>\r\n                        <div fxFlex=\"20px\">\r\n                            <mat-menu #itemMenu=\"matMenu\">\r\n                                <button mat-menu-item (click)=\"datatransferFacade.retryItem(item)\"\r\n                                    *ngIf=\"datatransferFacade.showRetryButtonByItem(item)\">\r\n                                    <mat-icon>refresh</mat-icon>\r\n                                    <span>Retry</span>\r\n                                </button>\r\n                                <button mat-menu-item (click)=\"datatransferFacade.removeItem(item)\">\r\n                                    <mat-icon>close</mat-icon>\r\n                                    <span>Remove</span>\r\n                                </button>\r\n                            </mat-menu>\r\n                            <button mat-icon-button [matMenuTriggerFor]=\"itemMenu\">\r\n                                <mat-icon>more_vert</mat-icon>\r\n                            </button>\r\n                        </div>\r\n                    </div>\r\n                </div>\r\n            </div>\r\n        </ng-template>\r\n    </div>\r\n\r\n    <div style=\"font-size: 12px; margin-top: 20px; text-align: right;\">\r\n        <amd-pagination [paginationService]=\"paginationService\"></amd-pagination>\r\n    </div>\r\n</div>"
            }] }
];
/** @nocollapse */
MainComponent.ctorParameters = () => [
    { type: DatatransferStore },
    { type: PaginationService }
];
MainComponent.propDecorators = {
    datatransferFacade: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    MainComponent.prototype.datatransferFacade;
    /** @type {?} */
    MainComponent.prototype.config;
    /** @type {?} */
    MainComponent.prototype.uploadProgress;
    /** @type {?} */
    MainComponent.prototype.downloadProgress;
    /** @type {?} */
    MainComponent.prototype.datatransferStore;
    /** @type {?} */
    MainComponent.prototype.paginationService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/services/logger.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// From: https://github.com/angular/angular/issues/5458
class LoggerService {
    constructor() {
        this.noop = (/**
         * @return {?}
         */
        () => { });
    }
    /**
     * @private
     * @return {?}
     */
    get enabled() {
        return !ConfigService.settings.production;
    }
    /**
     * @return {?}
     */
    get debug() {
        if (this.enabled) {
            return console.debug.bind(console);
        }
        return this.noop;
    }
    /**
     * @return {?}
     */
    get error() {
        if (this.enabled) {
            return console.error.bind(console);
        }
        return this.noop;
    }
    /**
     * @return {?}
     */
    get log() {
        if (this.enabled) {
            return console.log.bind(console);
        }
        return this.noop;
    }
    /**
     * @return {?}
     */
    get info() {
        if (this.enabled) {
            return console.info.bind(console);
        }
        return this.noop;
    }
    /**
     * @return {?}
     */
    get warn() {
        if (this.enabled) {
            return console.warn.bind(console);
        }
        return this.noop;
    }
}
LoggerService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
LoggerService.ctorParameters = () => [];
if (false) {
    /** @type {?} */
    LoggerService.prototype.noop;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/io/exporters/base.exporter.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IExporter() { }
if (false) {
    /**
     * @return {?}
     */
    IExporter.prototype.export = function () { };
}
/**
 * @abstract
 */
class BaseExporter {
    /**
     * @param {?} logger
     * @param {?} store
     */
    constructor(logger, store) {
        this.logger = logger;
        this.store = store;
    }
    /**
     * @protected
     * @param {?} content
     * @param {?} fileName
     * @param {?} mimeType
     * @return {?}
     */
    download(content, fileName, mimeType) {
        /** @type {?} */
        let a = document.createElement('a');
        mimeType = mimeType || 'application/octet-stream';
        if (navigator.msSaveBlob) { // IE10
            navigator.msSaveBlob(new Blob([content], {
                type: mimeType
            }), fileName);
        }
        else if (URL && 'download' in a) {
            a.href = URL.createObjectURL(new Blob([content], {
                type: mimeType
            }));
            a.setAttribute('download', fileName);
            document.body.appendChild(a);
            a.click();
            document.body.removeChild(a);
        }
        else {
            location.href = 'data:application/octet-stream,' + encodeURIComponent(content); // only this mime type is supported
        }
    }
}
BaseExporter.decorators = [
    { type: Injectable }
];
/** @nocollapse */
BaseExporter.ctorParameters = () => [
    { type: LoggerService },
    { type: DatatransferStore }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    BaseExporter.prototype.logger;
    /**
     * @type {?}
     * @protected
     */
    BaseExporter.prototype.store;
    /**
     * @abstract
     * @return {?}
     */
    BaseExporter.prototype.export = function () { };
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/io/exporters/csv.exporter.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CsvExporter extends BaseExporter {
    /**
     * @param {?} logger
     * @param {?} store
     */
    constructor(logger, store) {
        super(logger, store);
        this.logger = logger;
        this.store = store;
    }
    /**
     * @return {?}
     */
    export() {
        /** @type {?} */
        let csvContent = 'name,path,status,size,message\n';
        /** @type {?} */
        const items = this.store.getItems();
        items.forEach((/**
         * @param {?} item
         * @param {?} index
         * @return {?}
         */
        (item, index) => {
            /** @type {?} */
            const itemString = item.name + ',' + item.path + ',' + item.getStatusName() + ',' + item.sizeContainer.displaySize + ' ' +
                item.sizeContainer.displayUnit + ',' + item.message;
            csvContent += index < items.length ? itemString + '\n' : itemString;
        }));
        this.download(csvContent, 'export.csv', 'text/csv;encoding:utf-8');
    }
}
CsvExporter.decorators = [
    { type: Injectable }
];
/** @nocollapse */
CsvExporter.ctorParameters = () => [
    { type: LoggerService },
    { type: DatatransferStore }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    CsvExporter.prototype.logger;
    /**
     * @type {?}
     * @protected
     */
    CsvExporter.prototype.store;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/io/exporters/json.exporter.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class JsonExporter extends BaseExporter {
    /**
     * @param {?} logger
     * @param {?} store
     */
    constructor(logger, store) {
        super(logger, store);
        this.logger = logger;
        this.store = store;
    }
    /**
     * @return {?}
     */
    export() {
        /** @type {?} */
        const content = [];
        /** @type {?} */
        const items = this.store.getItems();
        items.forEach((/**
         * @param {?} item
         * @param {?} index
         * @return {?}
         */
        (item, index) => {
            content.push({
                name: item.name,
                path: item.path,
                status: item.getStatusName(),
                size: item.sizeContainer.displaySize + ' ' + item.sizeContainer.displayUnit,
                message: item.message
            });
        }));
        this.download(JSON.stringify(content, null, '\t'), 'export.json', 'text/json;encoding:utf-8');
    }
}
JsonExporter.decorators = [
    { type: Injectable }
];
/** @nocollapse */
JsonExporter.ctorParameters = () => [
    { type: LoggerService },
    { type: DatatransferStore }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    JsonExporter.prototype.logger;
    /**
     * @type {?}
     * @protected
     */
    JsonExporter.prototype.store;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/enums/export-type.enum.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
const ExportType = {
    CSV: 0,
    JSON: 1,
};
ExportType[ExportType.CSV] = 'CSV';
ExportType[ExportType.JSON] = 'JSON';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/services/export.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ExportService {
    /**
     * @param {?} csvExporter
     * @param {?} jsonExporter
     */
    constructor(csvExporter, jsonExporter) {
        this.csvExporter = csvExporter;
        this.jsonExporter = jsonExporter;
    }
    /**
     * @param {?} exportType
     * @return {?}
     */
    export(exportType) {
        /** @type {?} */
        let castedExportType = ExportType[exportType];
        switch (castedExportType) {
            case ExportType.CSV:
                this.csvExporter.export();
                break;
            case ExportType.JSON:
                this.jsonExporter.export();
                break;
            default:
                break;
        }
    }
}
ExportService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
ExportService.ctorParameters = () => [
    { type: CsvExporter },
    { type: JsonExporter }
];
if (false) {
    /**
     * @type {?}
     * @private
     */
    ExportService.prototype.csvExporter;
    /**
     * @type {?}
     * @private
     */
    ExportService.prototype.jsonExporter;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/models/preprocess-container.model.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IPreprocessContainer() { }
if (false) {
    /** @type {?} */
    IPreprocessContainer.prototype.percent;
    /**
     * @param {?} pause
     * @return {?}
     */
    IPreprocessContainer.prototype.pause = function (pause) { };
    /**
     * @return {?}
     */
    IPreprocessContainer.prototype.isPaused = function () { };
    /**
     * @param {?} cancel
     * @return {?}
     */
    IPreprocessContainer.prototype.cancel = function (cancel) { };
    /**
     * @return {?}
     */
    IPreprocessContainer.prototype.isCancelled = function () { };
    /**
     * @return {?}
     */
    IPreprocessContainer.prototype.doWork = function () { };
    /**
     * @return {?}
     */
    IPreprocessContainer.prototype.run = function () { };
}
class PreprocessContainer {
    /**
     * @param {?=} init
     */
    constructor(init) {
        this.percent = 0;
        this._isPaused = false;
        this._isCancelled = false;
        Object.assign(this, init);
    }
    /**
     * @param {?} pause
     * @return {?}
     */
    pause(pause) {
        this._isPaused = pause;
    }
    /**
     * @return {?}
     */
    isPaused() {
        return this._isPaused;
    }
    /**
     * @param {?} cancel
     * @return {?}
     */
    cancel(cancel) {
        this._isCancelled = cancel;
    }
    /**
     * @return {?}
     */
    isCancelled() {
        return this._isCancelled;
    }
    /**
     * @return {?}
     */
    doWork() {
    }
    /**
     * @return {?}
     */
    run() {
        this._isPaused = false;
        this.doWork();
    }
}
if (false) {
    /** @type {?} */
    PreprocessContainer.prototype.percent;
    /**
     * @type {?}
     * @private
     */
    PreprocessContainer.prototype._isPaused;
    /**
     * @type {?}
     * @private
     */
    PreprocessContainer.prototype._isCancelled;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/enums/hash-type.enum.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
const HashType = {
    MD5: 0,
    SHA1: 1,
};
HashType[HashType.MD5] = 'MD5';
HashType[HashType.SHA1] = 'SHA1';
/** @enum {number} */
const HashTypeImplementation = {
    Internal: 0,
    CryptoBrowserify: 1,
};
HashTypeImplementation[HashTypeImplementation.Internal] = 'Internal';
HashTypeImplementation[HashTypeImplementation.CryptoBrowserify] = 'CryptoBrowserify';
// tslint:disable-next-line: no-namespace
var HashTypeExtensions;
(function (HashTypeExtensions) {
    /**
     * @param {?} hashTypeImplementation
     * @param {?} hashType
     * @return {?}
     */
    function toString(hashTypeImplementation, hashType) {
        switch (hashType) {
            case HashType.MD5:
                return 'md5';
            case HashType.SHA1:
                return 'sha1';
            default:
                return 'sha1';
        }
    }
    HashTypeExtensions.toString = toString;
    /**
     * @param {?} hashTypeImplementation
     * @param {?} hashType
     * @return {?}
     */
    function toEnum(hashTypeImplementation, hashType) {
        switch (hashType) {
            case 'md5':
                return HashType.MD5;
            case 'sha1':
                return HashType.SHA1;
            default:
                return HashType.SHA1;
        }
    }
    HashTypeExtensions.toEnum = toEnum;
})(HashTypeExtensions || (HashTypeExtensions = {}));

/**
 * @fileoverview added by tsickle
 * Generated from: lib/enums/encoding-type.enum.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
const EncodingType = {
    Latin1: 0,
    Hex: 1,
    Base64: 2,
    UTF8: 3,
};
EncodingType[EncodingType.Latin1] = 'Latin1';
EncodingType[EncodingType.Hex] = 'Hex';
EncodingType[EncodingType.Base64] = 'Base64';
EncodingType[EncodingType.UTF8] = 'UTF8';
/** @enum {number} */
const EncodingTypeImplementation = {
    Internal: 0,
    CryptoBrowserify: 1,
};
EncodingTypeImplementation[EncodingTypeImplementation.Internal] = 'Internal';
EncodingTypeImplementation[EncodingTypeImplementation.CryptoBrowserify] = 'CryptoBrowserify';
// tslint:disable-next-line: no-namespace
var EncodingTypeExtensions;
(function (EncodingTypeExtensions) {
    /**
     * @param {?} encodingTypeImplementation
     * @param {?} encodingType
     * @return {?}
     */
    function toString(encodingTypeImplementation, encodingType) {
        switch (encodingType) {
            case EncodingType.Latin1:
                return 'latin1';
            case EncodingType.Hex:
                return 'hex';
            case EncodingType.Base64:
                return 'base64';
            case EncodingType.UTF8:
                return 'utf8';
            default:
                return 'hex';
        }
    }
    EncodingTypeExtensions.toString = toString;
    /**
     * @param {?} encodingTypeImplementation
     * @param {?} encodingType
     * @return {?}
     */
    function toEnum(encodingTypeImplementation, encodingType) {
        switch (encodingType) {
            case 'latin1':
                return EncodingType.Latin1;
            case 'hex':
                return EncodingType.Hex;
            case 'base64':
                return EncodingType.Base64;
            case 'utf8':
                return EncodingType.UTF8;
            default:
                return EncodingType.Hex;
        }
    }
    EncodingTypeExtensions.toEnum = toEnum;
})(EncodingTypeExtensions || (EncodingTypeExtensions = {}));

/**
 * @fileoverview added by tsickle
 * Generated from: lib/models/hash-container.model.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IHashContainer() { }
if (false) {
    /** @type {?} */
    IHashContainer.prototype.file;
    /** @type {?} */
    IHashContainer.prototype.hashType;
    /** @type {?} */
    IHashContainer.prototype.hashTypeString;
    /** @type {?} */
    IHashContainer.prototype.encodingType;
    /** @type {?} */
    IHashContainer.prototype.encodingTypeString;
    /** @type {?} */
    IHashContainer.prototype.inputEncodingType;
    /** @type {?} */
    IHashContainer.prototype.inputEncodingTypeString;
    /** @type {?} */
    IHashContainer.prototype.startDate;
    /** @type {?} */
    IHashContainer.prototype.endDate;
    /** @type {?} */
    IHashContainer.prototype.hash;
    /** @type {?} */
    IHashContainer.prototype.hashString;
    /** @type {?} */
    IHashContainer.prototype.reader;
}
/**
 * @record
 */
function IStreamHashContainer() { }
if (false) {
    /** @type {?} */
    IStreamHashContainer.prototype.chunkSize;
    /** @type {?} */
    IStreamHashContainer.prototype.offset;
}
class HashContainer extends PreprocessContainer {
    /**
     * @param {?} file
     * @param {?} hashTypeImplementation
     * @param {?} encodingTypeImplementation
     * @param {?} hashType
     * @param {?} encodingType
     * @param {?} inputEncodingType
     */
    constructor(file, hashTypeImplementation, encodingTypeImplementation, hashType, encodingType, inputEncodingType) {
        super();
        this.file = file;
        this.hashType = hashType;
        this.hashTypeString = HashTypeExtensions.toString(hashTypeImplementation, hashType);
        this.encodingType = encodingType;
        this.encodingTypeString = EncodingTypeExtensions.toString(encodingTypeImplementation, encodingType);
        this.inputEncodingType = inputEncodingType;
        this.inputEncodingTypeString = EncodingTypeExtensions.toString(encodingTypeImplementation, inputEncodingType);
        this.startDate = new Date();
        this.endDate = new Date();
        this.reader = new FileReader();
    }
}
if (false) {
    /** @type {?} */
    HashContainer.prototype.file;
    /** @type {?} */
    HashContainer.prototype.hashType;
    /** @type {?} */
    HashContainer.prototype.hashTypeString;
    /** @type {?} */
    HashContainer.prototype.encodingType;
    /** @type {?} */
    HashContainer.prototype.encodingTypeString;
    /** @type {?} */
    HashContainer.prototype.inputEncodingType;
    /** @type {?} */
    HashContainer.prototype.inputEncodingTypeString;
    /** @type {?} */
    HashContainer.prototype.startDate;
    /** @type {?} */
    HashContainer.prototype.endDate;
    /** @type {?} */
    HashContainer.prototype.hash;
    /** @type {?} */
    HashContainer.prototype.hashString;
    /** @type {?} */
    HashContainer.prototype.reader;
}
class StreamHashContainer extends HashContainer {
    /**
     * @param {?} file
     * @param {?} hashTypeImplementation
     * @param {?} encodingTypeImplementation
     * @param {?} hashType
     * @param {?} encodingType
     * @param {?} inputEncodingType
     */
    constructor(file, hashTypeImplementation, encodingTypeImplementation, hashType, encodingType, inputEncodingType) {
        super(file, hashTypeImplementation, encodingTypeImplementation, hashType, encodingType, inputEncodingType);
        this.chunkSize = 0;
        this.offset = 0;
    }
    /**
     * @param {?} cancel
     * @return {?}
     */
    cancel(cancel) {
        super.cancel(cancel);
        this.offset = 0;
    }
}
if (false) {
    /** @type {?} */
    StreamHashContainer.prototype.chunkSize;
    /** @type {?} */
    StreamHashContainer.prototype.offset;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/io/datatransfer.io.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IDatatransfer() { }
if (false) {
    /**
     * @param {?} event
     * @param {?} callback
     * @return {?}
     */
    IDatatransfer.prototype.on = function (event, callback) { };
    /**
     * @return {?}
     */
    IDatatransfer.prototype.isWorking = function () { };
    /**
     * @return {?}
     */
    IDatatransfer.prototype.startAll = function () { };
    /**
     * @return {?}
     */
    IDatatransfer.prototype.pauseAll = function () { };
    /**
     * @return {?}
     */
    IDatatransfer.prototype.removeAll = function () { };
    /**
     * @param {?} item
     * @return {?}
     */
    IDatatransfer.prototype.addItem = function (item) { };
    /**
     * @param {?} item
     * @return {?}
     */
    IDatatransfer.prototype.removeItem = function (item) { };
    /**
     * @param {?} item
     * @return {?}
     */
    IDatatransfer.prototype.retryItem = function (item) { };
}
/**
 * @abstract
 */
class BaseDatatransfer {
    /**
     * @param {?} logger
     * @param {?} guidUtil
     * @param {?} cryptoService
     */
    constructor(logger, guidUtil, cryptoService) {
        this.logger = logger;
        this.guidUtil = guidUtil;
        this.cryptoService = cryptoService;
        this.events = [];
        this._isWorking = false;
    }
    /**
     * @param {?} event
     * @param {?} callback
     * @return {?}
     */
    on(event, callback) {
        this.events.push(event.toLowerCase(), callback);
    }
    /**
     * @protected
     * @param {...?} args
     * @return {?}
     */
    fire(...args) {
        /** @type {?} */
        const event = args[0].toLowerCase();
        // Find event listeners, and support pseudo-event `catchAll`
        for (let i = 0; i <= this.events.length; i += 2) {
            if (this.events[i] === event) {
                this.events[i + 1].apply(this, args.slice(1));
            }
            if (this.events[i] === 'catchall') {
                this.events[i + 1].apply(null, args);
            }
        }
    }
    /**
     * @protected
     * @return {?}
     */
    updateZone() {
        this.fire('zoneUpdated');
    }
    /**
     * @protected
     * @param {?} item
     * @param {?} status
     * @param {?=} message
     * @return {?}
     */
    changeItemStatus(item, status, message) {
        this.fire('itemStatusChanged', item, status, message);
    }
    /**
     * @protected
     * @param {?} item
     * @param {?} progress
     * @return {?}
     */
    updateItemProgress(item, progress) {
        this.fire('itemProgressUpdated', item, progress);
    }
    /**
     * @protected
     * @param {?} transferType
     * @param {?} progress
     * @return {?}
     */
    updateOverallProgress(transferType, progress) {
        this.fire('overallProgressUpdated', transferType, progress);
    }
    /**
     * @protected
     * @param {?} size
     * @return {?}
     */
    updateOverallSize(size) {
        this.fire('overallSizeUpdated', size);
    }
    /**
     * @return {?}
     */
    isWorking() {
        return this._isWorking;
    }
    /**
     * @param {?} item
     * @return {?}
     */
    addItem(item) {
        this.fire('itemAdded', item);
    }
    /**
     * @protected
     * @return {?}
     */
    generateUniqueIdentifier() {
        return this.guidUtil.createGuid();
    }
    /**
     * @protected
     * @param {?} item
     * @param {?} file
     * @param {?} continueCallback
     * @param {?} cancelCallback
     * @return {?}
     */
    preprocessHash(item, file, continueCallback, cancelCallback) {
        /** @type {?} */
        const successCallback = (/**
         * @param {?} container
         * @return {?}
         */
        function (container) {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            if (container.hashString) {
                // const seconds = (container.endDate.getTime() - container.startDate.getTime()) / 1000;
                // console.log('file hashing took ' + seconds + ' seconds');
                /** @type {?} */
                const xhr = new XMLHttpRequest();
                /** @type {?} */
                const responseHandler = (/**
                 * @param {?} e
                 * @return {?}
                 */
                function (e) {
                    // ignore response if container has been cancelled
                    if (!container.isCancelled()) {
                        if (xhr.status === 200) {
                            item.message = xhr.responseText;
                            cancelCallback();
                        }
                        else {
                            continueCallback();
                        }
                    }
                });
                xhr.addEventListener('load', responseHandler, false);
                xhr.addEventListener('error', responseHandler, false);
                xhr.addEventListener('timeout', responseHandler, false);
                /** @type {?} */
                let params = [];
                params = params.concat([
                    [ConfigService.settings.core.preprocessHashParameterName, container.hashString],
                    [ConfigService.settings.core.preprocessHashFileNameParameterName, item.name]
                ]
                    .map((/**
                 * @param {?} pair
                 * @return {?}
                 */
                function (pair) {
                    return [
                        pair[0], encodeURIComponent(pair[1])
                    ].join('=');
                })));
                xhr.open(ConfigService.settings.core.preprocessHashMethod, ConfigService.settings.core.getTarget('preprocessHash', params));
                xhr.send(null);
            }
            else {
                continueCallback();
            }
        }).bind(this);
        /** @type {?} */
        const errorCallback = (/**
         * @param {?} event
         * @param {?} container
         * @return {?}
         */
        function (event, container) {
            console.log(event);
            continueCallback();
        });
        if (!item.preprocessContainer.isCancelled() && item.preprocessContainer instanceof StreamHashContainer) {
            // continue
        }
        else {
            /** @type {?} */
            const hashType = HashTypeExtensions.toEnum(HashTypeImplementation.Internal, ConfigService.settings.core.preprocessHashFunctionName);
            /** @type {?} */
            const encodingType = EncodingTypeExtensions.toEnum(EncodingTypeImplementation.Internal, ConfigService.settings.core.preprocessHashEncodingName);
            /** @type {?} */
            const inputEncodingType = EncodingTypeExtensions.toEnum(EncodingTypeImplementation.Internal, ConfigService.settings.core.preprocessHashInputEncodingName);
            item.preprocessContainer = this.cryptoService.createStreamHashContainer(file, hashType, encodingType, inputEncodingType, successCallback, errorCallback);
        }
        // wait for the initial mat-progress-spinner animation to complete
        setTimeout((/**
         * @return {?}
         */
        function () {
            item.preprocessContainer.run();
        }), 1000);
    }
}
if (false) {
    /**
     * @type {?}
     * @private
     */
    BaseDatatransfer.prototype.events;
    /**
     * @type {?}
     * @protected
     */
    BaseDatatransfer.prototype._isWorking;
    /**
     * @type {?}
     * @protected
     */
    BaseDatatransfer.prototype.logger;
    /**
     * @type {?}
     * @protected
     */
    BaseDatatransfer.prototype.guidUtil;
    /**
     * @type {?}
     * @protected
     */
    BaseDatatransfer.prototype.cryptoService;
    /**
     * @abstract
     * @return {?}
     */
    BaseDatatransfer.prototype.startAll = function () { };
    /**
     * @abstract
     * @return {?}
     */
    BaseDatatransfer.prototype.pauseAll = function () { };
    /**
     * @abstract
     * @return {?}
     */
    BaseDatatransfer.prototype.removeAll = function () { };
    /**
     * @abstract
     * @param {?} item
     * @return {?}
     */
    BaseDatatransfer.prototype.removeItem = function (item) { };
    /**
     * @abstract
     * @param {?} item
     * @return {?}
     */
    BaseDatatransfer.prototype.retryItem = function (item) { };
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/io/uploaders/base.uploader.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IUploader() { }
if (false) {
    /**
     * @param {?} element
     * @param {?} isDirectory
     * @return {?}
     */
    IUploader.prototype.assignBrowse = function (element, isDirectory) { };
    /**
     * @param {?} element
     * @return {?}
     */
    IUploader.prototype.assignDrop = function (element) { };
    /**
     * @param {?} oldPath
     * @param {?} newPath
     * @return {?}
     */
    IUploader.prototype.editPath = function (oldPath, newPath) { };
    /**
     * @param {?} item
     * @param {?} name
     * @return {?}
     */
    IUploader.prototype.editFilename = function (item, name) { };
}
/**
 * @abstract
 */
class BaseUploader extends BaseDatatransfer {
    /**
     * @param {?} logger
     * @param {?} guidUtil
     * @param {?} cryptoService
     */
    constructor(logger, guidUtil, cryptoService) {
        super(logger, guidUtil, cryptoService);
        this.logger = logger;
        this.guidUtil = guidUtil;
        this.cryptoService = cryptoService;
        this.filenameRegExp = new RegExp('[\/\\\\*?"<>:|]');
        this.pathRegExp = new RegExp('[*?"<>:|]');
        this.transferType = TransferType.Upload;
    }
    /**
     * @param {?} oldPath
     * @param {?} newPath
     * @return {?}
     */
    editPath(oldPath, newPath) {
        if (this.pathRegExp.test(newPath)) {
            throw new Error('A path cannot contain any of the following characters: * ? " < > : |');
        }
    }
    /**
     * @param {?} item
     * @param {?} name
     * @return {?}
     */
    editFilename(item, name) {
        if (!item) {
            throw new Error('Cannot edit the filename.');
        }
        if (!name) {
            throw new Error('Empty filename is not allowed.');
        }
        if (this.filenameRegExp.test(name)) {
            throw new Error('A filename cannot contain any of the following characters: \\ / * ? " < > : |');
        }
    }
}
if (false) {
    /**
     * @type {?}
     * @private
     */
    BaseUploader.prototype.filenameRegExp;
    /**
     * @type {?}
     * @private
     */
    BaseUploader.prototype.pathRegExp;
    /**
     * @type {?}
     * @protected
     */
    BaseUploader.prototype.transferType;
    /**
     * @type {?}
     * @protected
     */
    BaseUploader.prototype.logger;
    /**
     * @type {?}
     * @protected
     */
    BaseUploader.prototype.guidUtil;
    /**
     * @type {?}
     * @protected
     */
    BaseUploader.prototype.cryptoService;
    /**
     * @abstract
     * @param {?} element
     * @param {?} isDirectory
     * @return {?}
     */
    BaseUploader.prototype.assignBrowse = function (element, isDirectory) { };
    /**
     * @abstract
     * @param {?} element
     * @return {?}
     */
    BaseUploader.prototype.assignDrop = function (element) { };
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/utils/guid.util.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class GuidUtil {
    /**
     * @return {?}
     */
    createGuid() {
        /**
         * @return {?}
         */
        function s4() {
            return Math.floor((1 + Math.random()) * 0x10000).toString(16).substring(1);
        }
        return s4() + s4() + '-' + s4() + '-' + s4() + '-' + s4() + '-' + s4() + s4() + s4();
    }
}
GuidUtil.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/services/crypto.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CryptoService {
    /**
     * @param {?} zone
     */
    constructor(zone) {
        this.zone = zone;
        // hash 4MB at a time
        this.STREAM_HASH_CHUNK_SIZE = 1024 * 1000 * 4;
        this.HASH_TYPE_IMPLEMENTATION = HashTypeImplementation.CryptoBrowserify;
        this.ENCODING_TYPE_IMPLEMENTATION = EncodingTypeImplementation.CryptoBrowserify;
        // Performance remains unchanged by running the hash function outside of Angular.
        // this.zone.runOutsideAngular(() => { }
    }
    /**
     * @param {?} file
     * @param {?} hashType
     * @param {?} encodingType
     * @param {?} inputEncodingType
     * @return {?}
     */
    createHashContainer(file, hashType, encodingType, inputEncodingType) {
        /** @type {?} */
        const container = new HashContainer(file, this.HASH_TYPE_IMPLEMENTATION, this.ENCODING_TYPE_IMPLEMENTATION, hashType, encodingType, inputEncodingType);
        container.hash = createHash(container.hashTypeString);
        container.reader.onload = (/**
         * @param {?} event
         * @return {?}
         */
        function (event) {
            container.hashString = container.hash.update(event.target.result, container.inputEncodingTypeString)
                .digest(container.encodingTypeString);
            container.endDate = new Date();
            container.percent = 100;
        }).bind(container);
        container.doWork = (/**
         * @return {?}
         */
        function () {
            container.reader.readAsBinaryString(container.file);
        });
        return container;
    }
    /**
     * @param {?} file
     * @param {?} hashType
     * @param {?} encodingType
     * @param {?} inputEncodingType
     * @param {?} successCallback
     * @param {?} errorCallback
     * @return {?}
     */
    createStreamHashContainer(file, hashType, encodingType, inputEncodingType, successCallback, errorCallback) {
        /** @type {?} */
        const container = new StreamHashContainer(file, this.HASH_TYPE_IMPLEMENTATION, this.ENCODING_TYPE_IMPLEMENTATION, hashType, encodingType, inputEncodingType);
        container.chunkSize = this.STREAM_HASH_CHUNK_SIZE;
        container.offset = 0;
        container.hash = createHash(container.hashTypeString);
        container.reader.onload = (/**
         * @param {?} event
         * @return {?}
         */
        function (event) {
            /** @type {?} */
            const binary = event.target.result;
            if (container.offset + container.chunkSize >= container.file.size) {
                container.hash.end(binary, container.inputEncodingTypeString);
            }
            else {
                container.hash.write(binary, container.inputEncodingTypeString);
            }
            container.offset += container.chunkSize;
            container.doWork();
        }).bind(container);
        container.reader.onerror = (/**
         * @param {?} event
         * @return {?}
         */
        function (event) {
            errorCallback(event, container);
        });
        container.doWork = (/**
         * @return {?}
         */
        function () {
            if (!container.isCancelled() && !container.isPaused()) {
                if (container.offset > container.file.size) {
                    container.hashString = container.hash.read().toString(container.encodingTypeString);
                    container.endDate = new Date();
                    container.percent = 100;
                    successCallback(container);
                    return;
                }
                /** @type {?} */
                const slice = container.file.slice(container.offset, container.offset + container.chunkSize);
                container.reader.readAsBinaryString(slice);
                container.percent = Math.round(container.offset / file.size * 100);
            }
        });
        return container;
    }
}
CryptoService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
CryptoService.ctorParameters = () => [
    { type: NgZone }
];
if (false) {
    /**
     * @type {?}
     * @private
     */
    CryptoService.prototype.STREAM_HASH_CHUNK_SIZE;
    /**
     * @type {?}
     * @private
     */
    CryptoService.prototype.HASH_TYPE_IMPLEMENTATION;
    /**
     * @type {?}
     * @private
     */
    CryptoService.prototype.ENCODING_TYPE_IMPLEMENTATION;
    /**
     * @type {?}
     * @private
     */
    CryptoService.prototype.zone;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/models/datatransfer-item.model.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IDatatransferItem() { }
if (false) {
    /** @type {?} */
    IDatatransferItem.prototype.id;
    /** @type {?} */
    IDatatransferItem.prototype.name;
    /** @type {?} */
    IDatatransferItem.prototype.path;
    /** @type {?} */
    IDatatransferItem.prototype.displayPath;
    /** @type {?} */
    IDatatransferItem.prototype.sizeContainer;
    /** @type {?} */
    IDatatransferItem.prototype.transferType;
    /** @type {?} */
    IDatatransferItem.prototype.status;
    /** @type {?} */
    IDatatransferItem.prototype.preprocessContainer;
    /** @type {?} */
    IDatatransferItem.prototype.progressContainer;
    /** @type {?|undefined} */
    IDatatransferItem.prototype.message;
    /** @type {?|undefined} */
    IDatatransferItem.prototype.isSelected;
    /** @type {?|undefined} */
    IDatatransferItem.prototype.externalItem;
    /**
     * @return {?}
     */
    IDatatransferItem.prototype.getStatusName = function () { };
    /**
     * @return {?}
     */
    IDatatransferItem.prototype.getTransferTypeName = function () { };
}
class DatatransferItem {
    /**
     * @return {?}
     */
    get path() {
        return this._path;
    }
    /**
     * @param {?} newPath
     * @return {?}
     */
    set path(newPath) {
        this._path = newPath;
        this.displayPath = newPath;
        if (this.displayPath) {
            // remove last character
            if (this.displayPath.endsWith('/')) {
                this.displayPath = this.displayPath.slice(0, -1);
            }
            // replace all '/' with ' > '
            this.displayPath = this.displayPath.replace(/\//g, ' > ');
        }
    }
    /**
     * @return {?}
     */
    get message() {
        return this._message;
    }
    /**
     * @param {?} newMessage
     * @return {?}
     */
    set message(newMessage) {
        this._message = newMessage.toLowerCase().startsWith('<!doctype html') ? undefined : newMessage;
    }
    /**
     * @param {?=} init
     */
    constructor(init) {
        this.sizeContainer = new SizeContainer();
        this.preprocessContainer = new PreprocessContainer();
        this.progressContainer = new ProgressContainer(0);
        Object.assign(this, init);
    }
    /**
     * @return {?}
     */
    getStatusName() {
        return TransferStatus[this.status];
    }
    /**
     * @return {?}
     */
    getTransferTypeName() {
        return TransferType[this.transferType];
    }
}
if (false) {
    /** @type {?} */
    DatatransferItem.prototype.id;
    /** @type {?} */
    DatatransferItem.prototype.name;
    /**
     * @type {?}
     * @private
     */
    DatatransferItem.prototype._path;
    /** @type {?} */
    DatatransferItem.prototype.displayPath;
    /** @type {?} */
    DatatransferItem.prototype.sizeContainer;
    /** @type {?} */
    DatatransferItem.prototype.transferType;
    /** @type {?} */
    DatatransferItem.prototype.status;
    /** @type {?} */
    DatatransferItem.prototype.preprocessContainer;
    /** @type {?} */
    DatatransferItem.prototype.progressContainer;
    /**
     * @type {?}
     * @private
     */
    DatatransferItem.prototype._message;
    /** @type {?} */
    DatatransferItem.prototype.string;
    /** @type {?} */
    DatatransferItem.prototype.isSelected;
    /** @type {?} */
    DatatransferItem.prototype.externalItem;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/io/uploaders/resumablejs.uploader.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ResumableJsUploader extends BaseUploader {
    /**
     * @param {?} logger
     * @param {?} guidUtil
     * @param {?} cryptoService
     */
    constructor(logger, guidUtil, cryptoService) {
        super(logger, guidUtil, cryptoService);
        this.logger = logger;
        this.guidUtil = guidUtil;
        this.cryptoService = cryptoService;
        this.r = undefined;
        this.preprocessFileFn = undefined;
        this.preprocessChunkFn = undefined;
        this.initResumable();
    }
    /**
     * @private
     * @return {?}
     */
    initResumable() {
        /**
         * @param {?} file
         * @param {?} event
         * @return {?}
         */
        function generateId(file, event) {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            return that.generateUniqueIdentifier();
        }
        /**
         * @param {?} resumableChunk
         * @return {?}
         */
        function preprocessChunkInlineFn(resumableChunk) {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            if (typeof that.preprocessChunkFn === 'function') {
                that.preprocessChunkFn(resumableChunk);
            }
            else {
                resumableChunk.preprocessFinished();
            }
        }
        /**
         * @param {?} resumableFile
         * @return {?}
         */
        function preprocessFileInlineFn(resumableFile) {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            if (typeof that.preprocessFileFn === 'function') {
                that.changeItemStatus(resumableFile.internalItem, TransferStatus.Preprocessing);
                that.preprocessFileFn(resumableFile);
            }
            else {
                if (ConfigService.settings.core.preprocessHashEnabled && ConfigService.settings.core.preprocessHashChecked) {
                    that.changeItemStatus(resumableFile.internalItem, TransferStatus.Preprocessing);
                    /** @type {?} */
                    const continueCallback = (/**
                     * @return {?}
                     */
                    function () {
                        resumableFile.preprocessFinished();
                    });
                    /** @type {?} */
                    const cancelCallback = (/**
                     * @return {?}
                     */
                    function () {
                        resumableFile.cancel();
                        that.changeItemStatus(resumableFile.internalItem, TransferStatus.Finished, resumableFile.internalItem.message);
                        that.r.uploadNextChunk();
                    });
                    that.preprocessHash(resumableFile.internalItem, resumableFile.file, continueCallback, cancelCallback);
                }
                else {
                    resumableFile.preprocessFinished();
                }
            }
        }
        ConfigService.settings.resumablejs.generateUniqueIdentifier = generateId.bind(this);
        if (typeof ConfigService.settings.resumablejs.preprocess === 'function') {
            // clones the function with '{}' acting as it's new 'this' parameter
            this.preprocessChunkFn = ConfigService.settings.resumablejs.preprocess.bind({});
        }
        ConfigService.settings.resumablejs.preprocess = preprocessChunkInlineFn.bind(this);
        if (typeof ConfigService.settings.resumablejs.preprocessFile === 'function') {
            // clones the function with '{}' acting as it's new 'this' parameter
            this.preprocessFileFn = ConfigService.settings.resumablejs.preprocessFile.bind({});
        }
        ConfigService.settings.resumablejs.preprocessFile = preprocessFileInlineFn.bind(this);
        // @ts-ignore: ignore type checking
        this.r = new Resumable(ConfigService.settings.resumablejs);
        this.r.on('fileAdded', (/**
         * @param {?} file
         * @param {?} event
         * @return {?}
         */
        function (file, event) {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            // that.logger.log('fileAdded', file);
            /** @type {?} */
            const newItem = new DatatransferItem({
                id: file.uniqueIdentifier,
                name: file.fileName,
                path: file.relativePath.substr(0, file.relativePath.length - file.fileName.length),
                sizeContainer: new SizeContainer({ decimalByteUnit: DecimalByteUnit.Byte, decimalByteUnitSize: file.size }),
                progressContainer: new ProgressContainer(file.size),
                transferType: TransferType.Upload,
                status: TransferStatus.Ready,
                externalItem: file
            });
            file.internalItem = newItem;
            that.addItem(newItem);
        }).bind(this));
        this.r.on('fileProgress', (/**
         * @param {?} file
         * @param {?} message
         * @return {?}
         */
        function (file, message) {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            // that.logger.log('fileProgress', file.progress());
            that.changeItemStatus(file.internalItem, TransferStatus.Uploading);
            that.updateItemProgress(file.internalItem, file.progress());
            that.updateOverallProgress(that.transferType, that.r.progress());
        }).bind(this));
        this.r.on('fileSuccess', (/**
         * @param {?} file
         * @param {?} message
         * @return {?}
         */
        function (file, message) {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            // that.logger.log('fileSuccess', file);
            that.changeItemStatus(file.internalItem, TransferStatus.Finished, message);
        }).bind(this));
        this.r.on('fileError', (/**
         * @param {?} file
         * @param {?} message
         * @return {?}
         */
        function (file, message) {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            // that.logger.log('fileError', file, message);
            that.changeItemStatus(file.internalItem, TransferStatus.Failed, message);
        }).bind(this));
        this.r.on('uploadStart', (/**
         * @return {?}
         */
        function () {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            // that.logger.log('uploadStart', that.r);
            that._isWorking = true;
            that.updateZone();
            that.updateOverallProgress(that.transferType, that.r.progress());
            that.updateOverallSize(that.r.getSize());
        }).bind(this));
        this.r.on('chunkingComplete', (/**
         * @return {?}
         */
        function () {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            // that.logger.log('chunkingComplete');
        }).bind(this));
        this.r.on('pause', (/**
         * @return {?}
         */
        function () {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            // that.logger.log('pause');
            that._isWorking = false;
            that.updateZone();
        }).bind(this));
        this.r.on('cancel', (/**
         * @return {?}
         */
        function () {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            // that.logger.log('cancel');
            that._isWorking = false;
            that.updateZone();
        }).bind(this));
        this.r.on('complete', (/**
         * @return {?}
         */
        function () {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            // that.logger.log('complete', that.r);
            that._isWorking = false;
            that.updateZone();
        }).bind(this));
    }
    /**
     * @param {?} element
     * @param {?} isDirectory
     * @return {?}
     */
    assignBrowse(element, isDirectory) {
        this.r.assignBrowse(element, isDirectory);
    }
    /**
     * @param {?} element
     * @return {?}
     */
    assignDrop(element) {
        this.r.assignDrop(element);
    }
    /**
     * @param {?} oldPath
     * @param {?} newPath
     * @return {?}
     */
    editPath(oldPath, newPath) {
        super.editPath(oldPath, newPath);
        this.r.files.forEach((/**
         * @param {?} file
         * @param {?} index
         * @return {?}
         */
        (file, index) => {
            /** @type {?} */
            const internalItem = (/** @type {?} */ (file.internalItem));
            if (internalItem.status === TransferStatus.Ready && internalItem.path === oldPath) {
                file.relativePath = newPath + file.fileName;
                internalItem.path = newPath;
            }
        }));
    }
    /**
     * @param {?} item
     * @param {?} name
     * @return {?}
     */
    editFilename(item, name) {
        super.editFilename(item, name);
        item.externalItem.fileName = name;
        item.externalItem.relativePath = item.path + name;
        item.name = name;
    }
    /**
     * @return {?}
     */
    startAll() {
        this.r.upload();
    }
    /**
     * @return {?}
     */
    pauseAll() {
        // reset preprocessState
        this.r.files.forEach((/**
         * @param {?} file
         * @param {?} index
         * @return {?}
         */
        (file, index) => {
            if (file.preprocessState === 1) {
                file.preprocessState = 0;
            }
        }));
        this.r.pause();
    }
    /**
     * @return {?}
     */
    removeAll() {
        /** @type {?} */
        const tempFiles = this.r.files.slice();
        tempFiles.forEach((/**
         * @param {?} file
         * @param {?} index
         * @return {?}
         */
        (file, index) => {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            that.r.removeFile(file);
        }));
        this._isWorking = false;
    }
    /**
     * @param {?} item
     * @return {?}
     */
    removeItem(item) {
        this.r.removeFile(item.externalItem);
        if (this.r.files.length <= 0) {
            this._isWorking = false;
        }
    }
    /**
     * @param {?} item
     * @return {?}
     */
    retryItem(item) {
        item.externalItem.retry();
    }
}
ResumableJsUploader.decorators = [
    { type: Injectable }
];
/** @nocollapse */
ResumableJsUploader.ctorParameters = () => [
    { type: LoggerService },
    { type: GuidUtil },
    { type: CryptoService }
];
if (false) {
    /**
     * @type {?}
     * @private
     */
    ResumableJsUploader.prototype.r;
    /**
     * @type {?}
     * @private
     */
    ResumableJsUploader.prototype.preprocessFileFn;
    /**
     * @type {?}
     * @private
     */
    ResumableJsUploader.prototype.preprocessChunkFn;
    /**
     * @type {?}
     * @protected
     */
    ResumableJsUploader.prototype.logger;
    /**
     * @type {?}
     * @protected
     */
    ResumableJsUploader.prototype.guidUtil;
    /**
     * @type {?}
     * @protected
     */
    ResumableJsUploader.prototype.cryptoService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/io/downloaders/base.downloader.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IDownloader() { }
if (false) {
    /**
     * @param {?} filename
     * @param {?} url
     * @param {?} sizeInBytes
     * @return {?}
     */
    IDownloader.prototype.download = function (filename, url, sizeInBytes) { };
}
/**
 * @abstract
 */
class BaseDownloader extends BaseDatatransfer {
    /**
     * @param {?} logger
     * @param {?} guidUtil
     * @param {?} cryptoService
     */
    constructor(logger, guidUtil, cryptoService) {
        super(logger, guidUtil, cryptoService);
        this.logger = logger;
        this.guidUtil = guidUtil;
        this.cryptoService = cryptoService;
        this.transferType = TransferType.Download;
    }
}
if (false) {
    /**
     * @type {?}
     * @protected
     */
    BaseDownloader.prototype.transferType;
    /**
     * @type {?}
     * @protected
     */
    BaseDownloader.prototype.logger;
    /**
     * @type {?}
     * @protected
     */
    BaseDownloader.prototype.guidUtil;
    /**
     * @type {?}
     * @protected
     */
    BaseDownloader.prototype.cryptoService;
    /**
     * @abstract
     * @param {?} filename
     * @param {?} url
     * @param {?} sizeInBytes
     * @return {?}
     */
    BaseDownloader.prototype.download = function (filename, url, sizeInBytes) { };
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/utils/common.util.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CommonUtil {
    /**
     * @param {?} o
     * @param {?} callback
     * @return {?}
     */
    each(o, callback) {
        if (typeof (o.length) !== 'undefined') {
            for (let i = 0; i < o.length; i++) {
                // Array or FileList
                if (callback(o[i]) === false) {
                    return;
                }
            }
        }
        else {
            for (let i in o) {
                // Object
                if (callback(i, o[i]) === false) {
                    return;
                }
            }
        }
    }
}
CommonUtil.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/io/downloaders/blob.downloader.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BlobDownloader extends BaseDownloader {
    /**
     * @param {?} logger
     * @param {?} guidUtil
     * @param {?} cryptoService
     * @param {?} commonUtil
     */
    constructor(logger, guidUtil, cryptoService, commonUtil) {
        super(logger, guidUtil, cryptoService);
        this.logger = logger;
        this.guidUtil = guidUtil;
        this.cryptoService = cryptoService;
        this.commonUtil = commonUtil;
        this.throttleProgressCallbacks = 0.1;
        this.files = [];
        this.queue = [];
        this.downloading = [];
    }
    /**
     * @return {?}
     */
    startAll() {
        if (!this.isWorking()) {
            for (let index = 0; index < ConfigService.settings.core.simultaneousDownloads; index++) {
                this.downloadNext();
            }
        }
    }
    /**
     * @return {?}
     */
    pauseAll() {
    }
    /**
     * @return {?}
     */
    removeAll() {
        this.files.forEach((/**
         * @param {?} item
         * @param {?} index
         * @return {?}
         */
        (item, index) => {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            that.abortDownload(item);
        }));
        this.files.length = 0;
        this.queue.length = 0;
        this.downloading.length = 0;
        this._isWorking = false;
        this.updateOverallSize(this.getSize());
        this.updateOverallProgress(this.transferType, this.getProgress());
    }
    /**
     * @param {?} item
     * @return {?}
     */
    removeItem(item) {
        this.abortDownload(item);
        this.removeItemFromArray(item, this.files);
        this.removeItemFromArray(item, this.queue);
        this.removeItemFromArray(item, this.downloading);
        this.downloadNext();
    }
    /**
     * @private
     * @param {?} item
     * @param {?} array
     * @return {?}
     */
    removeItemFromArray(item, array) {
        for (let i = array.length - 1; i >= 0; i--) {
            if (array[i] === item) {
                array.splice(i, 1);
                break;
            }
        }
    }
    /**
     * @param {?} item
     * @return {?}
     */
    retryItem(item) {
        this.abortDownload(item);
        this.removeItemFromArray(item, this.queue);
        this.removeItemFromArray(item, this.downloading);
        this._isWorking = this.downloading.length > 0;
        item.externalItem.progress = 0;
        this.updateItemProgress(item, item.externalItem.progress);
        this.changeItemStatus(item, TransferStatus.Queued);
        this.queue.push(item);
        this.initDownload(item);
        this.downloadNext();
    }
    /**
     * @param {?} filename
     * @param {?} url
     * @param {?} sizeInBytes
     * @return {?}
     */
    download(filename, url, sizeInBytes) {
        /** @type {?} */
        const newItem = new DatatransferItem({
            id: this.generateUniqueIdentifier(),
            name: filename,
            sizeContainer: new SizeContainer({ decimalByteUnit: DecimalByteUnit.Byte, decimalByteUnitSize: sizeInBytes }),
            progressContainer: new ProgressContainer(sizeInBytes),
            transferType: TransferType.Download,
            status: TransferStatus.Queued,
            externalItem: {
                url,
                progress: 0,
                size: sizeInBytes,
                lastProgressCallback: new Date()
            }
        });
        this.addItem(newItem);
        this.files.push(newItem);
        this.queue.push(newItem);
        this.initDownload(newItem);
        this.downloadNext();
    }
    /**
     * @private
     * @param {?} item
     * @return {?}
     */
    initDownload(item) {
        /** @type {?} */
        const xhr = new XMLHttpRequest();
        item.externalItem.xhr = xhr;
        xhr.open(ConfigService.settings.core.downloadMethod, item.externalItem.url);
        xhr.timeout = ConfigService.settings.core.downloadXhrTimeout;
        xhr.withCredentials = ConfigService.settings.core.downloadWithCredentials;
        // Add data from header options
        /** @type {?} */
        let customHeaders = ConfigService.settings.core.downloadHeaders;
        if (typeof customHeaders === 'function') {
            customHeaders = customHeaders(item);
        }
        this.commonUtil.each(customHeaders, (/**
         * @param {?} k
         * @param {?} v
         * @return {?}
         */
        function (k, v) {
            xhr.setRequestHeader(k, v);
        }));
        xhr.responseType = 'blob';
        xhr.onloadstart = (/**
         * @param {?} e
         * @return {?}
         */
        function (e) {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            that.changeItemStatus(item, TransferStatus.Downloading);
        }).bind(this);
        xhr.onprogress = (/**
         * @param {?} e
         * @return {?}
         */
        function (e) {
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            if (new Date().getTime() - item.externalItem.lastProgressCallback.getTime() > that.throttleProgressCallbacks * 1000) {
                item.externalItem.progress = e.loaded / e.total;
                that.updateItemProgress(item, item.externalItem.progress);
                that.updateOverallProgress(that.transferType, that.getProgress());
                item.externalItem.lastProgressCallback = new Date();
            }
        }).bind(this);
        xhr.onloadend = (/**
         * @param {?} e
         * @return {?}
         */
        function (e) {
            /*
                        Value	State	Description
                        0	UNSENT	Client has been created. open() not called yet.
                        1	OPENED	open() has been called.
                        2	HEADERS_RECEIVED	send() has been called, and headers and status are available.
                        3	LOADING	Downloading; responseText holds partial data.
                        4	DONE	The operation is complete.
                        */
            /** @type {?} */
            const that = (/** @type {?} */ (this));
            if (xhr.readyState === 4) {
                item.externalItem.progress = 1;
                that.updateItemProgress(item, item.externalItem.progress);
                if (xhr.status === 200) {
                    that.changeItemStatus(item, TransferStatus.Finished);
                    saveAs(xhr.response, item.name);
                }
                else if (xhr.status !== 0) { // don't change status for aborted items
                    that.changeItemStatus(item, TransferStatus.Failed);
                }
                that.removeItemFromArray(item, that.downloading);
                that.downloadNext();
            }
        }).bind(this);
    }
    /**
     * @private
     * @return {?}
     */
    downloadNext() {
        this.updateOverallSize(this.getSize());
        this.updateOverallProgress(this.transferType, this.getProgress());
        if (this.downloading.length < ConfigService.settings.core.simultaneousDownloads) {
            /** @type {?} */
            const item = this.queue.shift();
            if (!!item && !!item.externalItem && !!item.externalItem.xhr) {
                this.changeItemStatus(item, TransferStatus.Downloading);
                this.downloading.push(item);
                this._isWorking = this.downloading.length > 0;
                item.externalItem.xhr.send();
            }
        }
    }
    /**
     * @private
     * @param {?} item
     * @return {?}
     */
    abortDownload(item) {
        if (!!item && !!item.externalItem && !!item.externalItem.xhr) {
            item.externalItem.xhr.abort();
            item.externalItem.xhr = null;
        }
    }
    /**
     * @private
     * @return {?}
     */
    getSize() {
        /** @type {?} */
        let totalSize = 0;
        this.files.forEach((/**
         * @param {?} file
         * @param {?} index
         * @return {?}
         */
        (file, index) => {
            totalSize += file.externalItem.size;
        }));
        return totalSize;
    }
    /**
     * @private
     * @return {?}
     */
    getProgress() {
        /** @type {?} */
        let totalDone = 0;
        /** @type {?} */
        let totalSize = 0;
        this.files.forEach((/**
         * @param {?} file
         * @param {?} index
         * @return {?}
         */
        (file, index) => {
            /** @type {?} */
            let currentFileProgress = file.externalItem.progress;
            if (file.status === TransferStatus.Failed) {
                currentFileProgress = 1;
            }
            totalDone += currentFileProgress * file.externalItem.size;
            totalSize += file.externalItem.size;
        }));
        return totalSize > 0 ? totalDone / totalSize : 0;
    }
}
BlobDownloader.decorators = [
    { type: Injectable }
];
/** @nocollapse */
BlobDownloader.ctorParameters = () => [
    { type: LoggerService },
    { type: GuidUtil },
    { type: CryptoService },
    { type: CommonUtil }
];
if (false) {
    /**
     * @type {?}
     * @private
     */
    BlobDownloader.prototype.throttleProgressCallbacks;
    /**
     * @type {?}
     * @private
     */
    BlobDownloader.prototype.files;
    /**
     * @type {?}
     * @private
     */
    BlobDownloader.prototype.queue;
    /**
     * @type {?}
     * @private
     */
    BlobDownloader.prototype.downloading;
    /**
     * @type {?}
     * @protected
     */
    BlobDownloader.prototype.logger;
    /**
     * @type {?}
     * @protected
     */
    BlobDownloader.prototype.guidUtil;
    /**
     * @type {?}
     * @protected
     */
    BlobDownloader.prototype.cryptoService;
    /**
     * @type {?}
     * @private
     */
    BlobDownloader.prototype.commonUtil;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/factories/datatransfer-facade.factory.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DatatransferFacadeFactory {
    /**
     * @param {?} logger
     * @param {?} zone
     * @param {?} store
     * @param {?} dateUtil
     * @param {?} paginationService
     * @param {?} exportService
     * @param {?} dialog
     * @param {?} resumableUploader
     * @param {?} blobDownloader
     */
    constructor(logger, zone, store, dateUtil, paginationService, exportService, dialog, resumableUploader, blobDownloader) {
        this.logger = logger;
        this.zone = zone;
        this.store = store;
        this.dateUtil = dateUtil;
        this.paginationService = paginationService;
        this.exportService = exportService;
        this.dialog = dialog;
        this.resumableUploader = resumableUploader;
        this.blobDownloader = blobDownloader;
    }
    // TODO: pass arguments to define which uploader/downloader implementation should be used
    /**
     * @return {?}
     */
    createDatatransferFacade() {
        if (!this.facade1) {
            this.facade1 = new DatatransferFacade(this.logger, this.zone, this.store, this.dateUtil, this.paginationService, this.exportService, this.resumableUploader, this.blobDownloader, this.dialog);
        }
        return this.facade1;
    }
}
DatatransferFacadeFactory.decorators = [
    { type: Injectable }
];
/** @nocollapse */
DatatransferFacadeFactory.ctorParameters = () => [
    { type: LoggerService },
    { type: NgZone },
    { type: DatatransferStore },
    { type: DateUtil },
    { type: PaginationService },
    { type: ExportService },
    { type: MatDialog },
    { type: ResumableJsUploader },
    { type: BlobDownloader }
];
if (false) {
    /**
     * @type {?}
     * @private
     */
    DatatransferFacadeFactory.prototype.facade1;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacadeFactory.prototype.logger;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacadeFactory.prototype.zone;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacadeFactory.prototype.store;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacadeFactory.prototype.dateUtil;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacadeFactory.prototype.paginationService;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacadeFactory.prototype.exportService;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacadeFactory.prototype.dialog;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacadeFactory.prototype.resumableUploader;
    /**
     * @type {?}
     * @private
     */
    DatatransferFacadeFactory.prototype.blobDownloader;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/angular-material-datatransfer.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AngularMaterialDatatransferComponent {
    /**
     * @param {?} componentFactoryResolver
     * @param {?} datatransferFacadeFactory
     * @param {?} configService
     * @param {?} paginationService
     */
    constructor(componentFactoryResolver, datatransferFacadeFactory, configService, paginationService) {
        this.componentFactoryResolver = componentFactoryResolver;
        this.datatransferFacadeFactory = datatransferFacadeFactory;
        this.configService = configService;
        this.paginationService = paginationService;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        document.dispatchEvent(new Event(CustomEventTypeExtensions.toString(CustomEventType.INIT)));
    }
    /**
     * @param {?} config
     * @return {?}
     */
    create(config) {
        this.setConfig(config);
    }
    /**
     * @param {?} config
     * @return {?}
     */
    setConfig(config) {
        this.configService.load(config);
        this.paginationService.setRppOptions(ConfigService.settings.core.paginationRppOptions);
        this.datatransferFacade = this.datatransferFacadeFactory.createDatatransferFacade();
        /** @type {?} */
        const viewContainerRef = this.amdHost.viewContainerRef;
        viewContainerRef.clear();
        /** @type {?} */
        const componentFactory = this.componentFactoryResolver.resolveComponentFactory(MainComponent);
        /** @type {?} */
        const componentRef = viewContainerRef.createComponent(componentFactory);
        /** @type {?} */
        const componentRefInstance = (/** @type {?} */ (componentRef.instance));
        componentRefInstance.datatransferFacade = this.datatransferFacade;
    }
    /**
     * @param {?} filename
     * @param {?} url
     * @param {?} size
     * @return {?}
     */
    download(filename, url, size) {
        this.datatransferFacade.download(filename, url, size);
    }
}
AngularMaterialDatatransferComponent.decorators = [
    { type: Component, args: [{
                // tslint:disable-next-line:component-selector
                selector: 'angular-material-datatransfer-lib',
                template: "<div class=\"angular-material-datatransfer\">\r\n    <ng-template amd-host></ng-template>\r\n</div>"
            }] }
];
/** @nocollapse */
AngularMaterialDatatransferComponent.ctorParameters = () => [
    { type: ComponentFactoryResolver },
    { type: DatatransferFacadeFactory },
    { type: ConfigService },
    { type: PaginationService }
];
AngularMaterialDatatransferComponent.propDecorators = {
    amdHost: [{ type: ViewChild, args: [HostDirective, { static: true },] }]
};
if (false) {
    /** @type {?} */
    AngularMaterialDatatransferComponent.prototype.amdHost;
    /**
     * @type {?}
     * @private
     */
    AngularMaterialDatatransferComponent.prototype.datatransferFacade;
    /**
     * @type {?}
     * @private
     */
    AngularMaterialDatatransferComponent.prototype.componentFactoryResolver;
    /**
     * @type {?}
     * @private
     */
    AngularMaterialDatatransferComponent.prototype.datatransferFacadeFactory;
    /**
     * @type {?}
     * @private
     */
    AngularMaterialDatatransferComponent.prototype.configService;
    /**
     * @type {?}
     * @private
     */
    AngularMaterialDatatransferComponent.prototype.paginationService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/dropzone.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DropzoneComponent {
    constructor() { }
}
DropzoneComponent.decorators = [
    { type: Component, args: [{
                // tslint:disable-next-line:component-selector
                selector: 'amd-dropzone',
                template: "<div class=\"amd-dropzone\" id=\"amd-dropzone-component\">\r\n    <div class=\"amd-dropzone-content\">\r\n        <mat-icon style=\"font-size: 64px; color: rgba(255, 255, 255, 1);\">insert_drive_file</mat-icon>\r\n        <mat-icon style=\"margin-left: 10px;\">add_circle_outline</mat-icon>\r\n        <p>Drop your files/folders here or click to upload.</p>\r\n    </div>\r\n</div>"
            }] }
];
/** @nocollapse */
DropzoneComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/pagination.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PaginationComponent {
    /**
     * @param {?} logger
     */
    constructor(logger) {
        this.logger = logger;
    }
    /**
     * @return {?}
     */
    max() {
        return this.paginationService.max();
    }
    ;
    /**
     * @return {?}
     */
    min() {
        return this.paginationService.min();
    }
    ;
    /**
     * @return {?}
     */
    first() {
        this.paginationService.first();
    }
    /**
     * @return {?}
     */
    last() {
        this.paginationService.last();
    }
    /**
     * @return {?}
     */
    hasNext() {
        return this.paginationService.hasNext();
    }
    /**
     * @return {?}
     */
    hasPrevious() {
        return this.paginationService.hasPrevious();
    }
    ;
    /**
     * @return {?}
     */
    moveNext() {
        this.paginationService.moveNext();
    }
    /**
     * @return {?}
     */
    movePrevious() {
        this.paginationService.movePrevious();
    }
    /**
     * @return {?}
     */
    onPageChange() {
        this.paginationService.onPageChange();
    }
    /**
     * @return {?}
     */
    onRppChange() {
        this.paginationService.onRppChange();
    }
    /**
     * @return {?}
     */
    onPaginationChange() {
        this.paginationService.onPaginationChange();
    }
    /**
     * @return {?}
     */
    pageCount() {
        return this.paginationService.pageCount();
    }
}
PaginationComponent.decorators = [
    { type: Component, args: [{
                // tslint:disable-next-line:component-selector
                selector: 'amd-pagination',
                template: "<mat-form-field>\r\n    <mat-select placeholder=\"Page\" [(ngModel)]=\"paginationService.pagination.page\" (change)=\"onPageChange()\" aria-label=\"Page\">\r\n        <mat-option *ngFor=\"let p of paginationService.pagination.pages\" [value]=\"p\">\r\n            {{ p }}\r\n        </mat-option>\r\n    </mat-select>\r\n</mat-form-field>\r\n<mat-form-field>\r\n    <mat-select placeholder=\"Rows per page\" [(ngModel)]=\"paginationService.pagination.rpp\" (change)=\"onRppChange()\" aria-label=\"Rows per page\">\r\n        <mat-option *ngFor=\"let o of paginationService.pagination.rppOptions\" [value]=\"o\">\r\n            {{ o }}\r\n        </mat-option>\r\n    </mat-select>\r\n</mat-form-field>\r\n<span>{{min()}} - {{max()}} of {{paginationService.pagination.total}}</span>\r\n<button mat-icon-button mat-button (click)=\"movePrevious()\" [disabled]=\"!hasPrevious()\">\r\n    <mat-icon>navigate_before</mat-icon>\r\n</button>\r\n<button mat-icon-button mat-button (click)=\"moveNext()\" [disabled]=\"!hasNext()\">\r\n    <mat-icon>navigate_next</mat-icon>\r\n</button>"
            }] }
];
/** @nocollapse */
PaginationComponent.ctorParameters = () => [
    { type: LoggerService }
];
PaginationComponent.propDecorators = {
    paginationService: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    PaginationComponent.prototype.paginationService;
    /**
     * @type {?}
     * @private
     */
    PaginationComponent.prototype.logger;
    /* Skipping unhandled member: ;*/
    /* Skipping unhandled member: ;*/
    /* Skipping unhandled member: ;*/
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/progress.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ProgressComponent {
    constructor() { }
}
ProgressComponent.decorators = [
    { type: Component, args: [{
                // tslint:disable-next-line:component-selector
                selector: 'amd-progress',
                template: "<div style=\"font-size: 11px; margin-top: 10px;\">\r\n    <div fxFlex=\"25%\" fxFlex.lt-md=\"50%\">\r\n        {{progressContainer.displayBitrate}}\r\n    </div>\r\n    <div fxFlex=\"25%\" fxHide.lt-md style=\"text-align: center\">\r\n        {{progressContainer.displayTimeLeft}}\r\n    </div>\r\n    <div fxFlex=\"25%\" fxHide.lt-md style=\"text-align: center\">\r\n        {{progressContainer.percent}}%\r\n    </div>\r\n    <div fxFlex=\"25%\" fxFlex.lt-md=\"50%\" style=\"text-align: right\">\r\n        {{progressContainer.loadedSizeContainer.displaySize}} / {{progressContainer.totalSizeContainer.displaySize}} {{progressContainer.totalSizeContainer.displayUnit}}\r\n    </div>\r\n</div>\r\n<mat-progress-bar *ngIf=\"progressContainer.total > 0\" [value]=\"progressContainer.percent\">\r\n</mat-progress-bar>"
            }] }
];
/** @nocollapse */
ProgressComponent.ctorParameters = () => [];
ProgressComponent.propDecorators = {
    progressContainer: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    ProgressComponent.prototype.progressContainer;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/services/demo.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DemoService {
    constructor() {
        this.title = 'angular-material-datatransfer';
        this.testItems = [
            new DatatransferItem({
                id: '1',
                name: 'DICOM_patientXY_1.dcm',
                path: '/mnt/sdcard/folder1/a/b/',
                sizeContainer: new SizeContainer({ decimalByteUnit: DecimalByteUnit.MB, decimalByteUnitSize: 15 }),
                progressContainer: new ProgressContainer(15 * 1000 * 1000),
                transferType: TransferType.Upload,
                status: TransferStatus.Uploading
            }),
            new DatatransferItem({
                id: '2',
                name: 'DICOM_patientXY_2.dcm',
                path: '/mnt/sdcard/folder1/a/b/',
                sizeContainer: new SizeContainer({ decimalByteUnit: DecimalByteUnit.MB, decimalByteUnitSize: 17 }),
                transferType: TransferType.Upload,
                status: TransferStatus.Failed
            }),
            new DatatransferItem({
                id: '3',
                name: 'DICOM_patientXY_3.dcm',
                path: '/mnt/sdcard/folder1/a/b/',
                preprocessContainer: new PreprocessContainer({ percent: 30 }),
                sizeContainer: new SizeContainer({ decimalByteUnit: DecimalByteUnit.MB, decimalByteUnitSize: 13 }),
                transferType: TransferType.Upload,
                status: TransferStatus.Preprocessing
            }),
            new DatatransferItem({
                id: '4',
                name: 'DICOM_patientXY_4.dcm',
                path: '/mnt/sdcard/folder1/a/b/',
                sizeContainer: new SizeContainer({ decimalByteUnit: DecimalByteUnit.MB, decimalByteUnitSize: 11 }),
                transferType: TransferType.Upload,
                status: TransferStatus.Queued,
            }),
            new DatatransferItem({
                id: '5',
                name: 'SMIR.Thorax.089Y.M.CT.7.000.dcm.zip',
                path: '/',
                sizeContainer: new SizeContainer({ decimalByteUnit: DecimalByteUnit.GB, decimalByteUnitSize: 2 }),
                transferType: TransferType.Download,
                status: TransferStatus.Queued
            }),
            new DatatransferItem({
                id: '6',
                name: 'NIFTI_patientXY.nii',
                path: '/mnt/sdcard/folder2/d/',
                sizeContainer: new SizeContainer({ decimalByteUnit: DecimalByteUnit.GB, decimalByteUnitSize: 12 }),
                transferType: TransferType.Upload,
                status: TransferStatus.Queued,
            })
        ];
    }
}
DemoService.decorators = [
    { type: Injectable }
];
if (false) {
    /** @type {?} */
    DemoService.prototype.title;
    /** @type {?} */
    DemoService.prototype.testItems;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/angular-material-datatransfer.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AngularMaterialDatatransferModule {
    /**
     * @param {?} appRef
     */
    constructor(appRef) {
        this.appRef = appRef;
    }
}
AngularMaterialDatatransferModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    AngularMaterialDatatransferComponent,
                    MainComponent,
                    BrowseDialogComponent,
                    DropzoneComponent,
                    EditDialogComponent,
                    PaginationComponent,
                    ProgressComponent,
                    HostDirective
                ],
                imports: [
                    BrowserModule,
                    BrowserAnimationsModule,
                    FormsModule,
                    ReactiveFormsModule,
                    MatButtonModule,
                    MatCheckboxModule,
                    MatDialogModule,
                    MatFormFieldModule,
                    MatIconModule,
                    MatInputModule,
                    MatMenuModule,
                    MatOptionModule,
                    MatProgressBarModule,
                    MatProgressSpinnerModule,
                    MatSelectModule,
                    MatTooltipModule,
                    FlexLayoutModule
                ],
                exports: [AngularMaterialDatatransferComponent],
                entryComponents: [
                    MainComponent,
                    BrowseDialogComponent,
                    EditDialogComponent
                ],
                providers: [
                    ConfigService,
                    LoggerService,
                    PaginationService,
                    ExportService,
                    DemoService,
                    CryptoService,
                    DatatransferStore,
                    DatatransferFacadeFactory,
                    CommonUtil,
                    DateUtil,
                    DecimalByteUnitUtil,
                    GuidUtil,
                    CsvExporter,
                    JsonExporter,
                    ResumableJsUploader,
                    BlobDownloader
                ]
            },] }
];
/** @nocollapse */
AngularMaterialDatatransferModule.ctorParameters = () => [
    { type: ApplicationRef }
];
if (false) {
    /** @type {?} */
    AngularMaterialDatatransferModule.prototype.appRef;
}

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: angular-material-datatransfer-lib.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { AngularMaterialDatatransferComponent, AngularMaterialDatatransferModule, HostDirective as ɵa, DatatransferFacadeFactory as ɵb, DemoService as ɵba, DecimalByteUnitUtil as ɵbb, LoggerService as ɵc, DatatransferStore as ɵd, DateUtil as ɵe, PaginationService as ɵf, ExportService as ɵg, CsvExporter as ɵh, BaseExporter as ɵi, JsonExporter as ɵj, ResumableJsUploader as ɵk, BaseUploader as ɵl, BaseDatatransfer as ɵm, GuidUtil as ɵn, CryptoService as ɵo, BlobDownloader as ɵp, BaseDownloader as ɵq, CommonUtil as ɵr, ConfigService as ɵs, AppConfig as ɵt, MainComponent as ɵu, BrowseDialogComponent as ɵv, DropzoneComponent as ɵw, EditDialogComponent as ɵx, PaginationComponent as ɵy, ProgressComponent as ɵz };
//# sourceMappingURL=angular-material-datatransfer-lib.js.map
